<?
// --------------------------------------------------------------------------------
// PhpWindowSystem - PwsMenu Class
// --------------------------------------------------------------------------------
//
// Presentation :
//   PhpWindowSystem is a generic PHP window system management.
//   PhpWindowSystem is designed to take care of window displaying and
//   manage the associated events in order to offer a generic application
//   container.
//   More information can be obtained on
//   PhpConcept (http://www.phpconcept.net)
//   or by contacting the author Vincent Blavet (vincent@phpconcept.net)
//
// --------------------------------------------------------------------------------
// License :
//   PhpWindowSystem (PWS)
//   Copyright (C) 2002  Vincent Blavet (vincent@phpconcept.net)
//
//   This library is free software; you can redistribute it and/or
//   modify it under the terms of the GNU Lesser General Public
//   License as published by the Free Software Foundation; either
//   version 2.1 of the License, or (at your option) any later version.
//
//   This library is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//   Lesser General Public License for more details.
//
//   You should have received a copy of the GNU Lesser General Public
//   License along with this library; if not, write to the Free Software
//   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// --------------------------------------------------------------------------------
// CVS : $Id: pws-menu.class.php,v 1.1 2002/08/26 22:07:43 vblavet Exp $
// --------------------------------------------------------------------------------

  // ----- Class objects
  require_once('pws/core/pws-object-graphical.class.php');
  require_once('pws/core/pws-button.class.php');
  require_once('pws/core/pws-separator.class.php');

  // ----- Constant definition
  define ("PWS_MENU_DEFAULT_NONE", 0);
  define ("PWS_MENU_DEFAULT_FILE", 1);
  define ("PWS_MENU_DEFAULT_EDIT", 2);
  define ("PWS_MENU_DEFAULT_WINDOW", 4);
  define ("PWS_MENU_DEFAULT_HELP", 8);

  define ("PWS_MENU_TYPE_TOOLBAR", 0);
  define ("PWS_MENU_TYPE_POPUP", 1);
  define ("PWS_MENU_TYPE_DOCUMENT_LIST", 2);

  // ----- Class ID
  define ('PWS_MENU_ID', 10070000);

  // ----- Attributes definition
  define ('PWS_MENU_ATTRIBUTE_TYPE', PWS_MENU_ID+1);

  // --------------------------------------------------------------------------------
  // Class : PwsMenu
  // Description :
  // Attributes :
  // --------------------------------------------------------------------------------
  class PwsMenu extends PwsObjectGraphical
  {
    // ----- Object attributes
    var $type;

    // --------------------------------------------------------------------------------
    // Method : PwsMenu()
    // Description :
    //   Constructor
    // --------------------------------------------------------------------------------
    function PwsMenu()
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsMenu::PwsMenu', "");

      // ----- Call the Parent constructor
      PwsObjectGraphical::PwsObjectGraphical();

      // ----- Initialize
      $this->type = PWS_MENU_TYPE_TOOLBAR;

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : pSetSingleAttribute()
    // Description :
    // --------------------------------------------------------------------------------
    function pSetSingleAttribute($p_name, $p_value)
    {
      $v_result=1;
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsMenu::pSetSingleAttribute', "name='$p_name', value='$p_value'");

      // ----- Look first for parent class attribute
      if (($v_result = PwsObjectGraphical::pSetSingleAttribute($p_name, $p_value)) == 0) {
        // ----- Set the attribute
        switch ($p_name)
        {
          case PWS_MENU_ATTRIBUTE_TYPE :
            $this->type = $p_value;
          break;
          default :
            PwsTraceFctMessage(__FILE__, __LINE__, 2, "Unknown attribute '$p_name' for PwsMenu object");
            $v_result=0;
        }
      }

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, $v_result);
      return $v_result;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : add()
    // Description :
    // --------------------------------------------------------------------------------
    function add($p_child, $p_index=-1)
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsMenu['.$this->id.']::add', "child='".$p_child->id."', index=$p_index");

      // ----- Add a child
      $nb = sizeof($this->childs);
      PwsTraceFctMessage(__FILE__, __LINE__, 2, "Adding child at index $nb");
      $this->childs[$nb] = &$p_child;
      $p_child->pAttach(&$this, $p_index);

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : readXmlToken()
    // Description :
    // --------------------------------------------------------------------------------
    function readXmlToken($p_parser, $p_name, $attrs)
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsMenu['.$this->id.']::readXmlToken', "name='$p_name'");

      // ----- Look for token name
      switch ($p_name)
      {
        case "BUTTON" :
          PwsTraceFctMessage(__FILE__, __LINE__, 2, "Found token BUTTON, create object");

          // ----- Create a new Title object
          $p_button = new PwsButton();
          $this->add(&$p_button);

          // ----- Set the object & methods for the xml parser
          xml_set_object($p_parser, &$p_button);
        break;

        case "SEPARATOR" :
          PwsTraceFctMessage(__FILE__, __LINE__, 2, "Found token SEPARATOR, create object");

          // ----- Create a new Title object
          $p_object = new PwsSeparator();
          $this->add(&$p_object);

          // ----- Set the object & methods for the xml parser
          xml_set_object($p_parser, &$p_object);
        break;

        case "MENU" :
          PwsTraceFctMessage(__FILE__, __LINE__, 2, "Found token MENU, create object");

          // ----- Create a new object
          $p_object = new PwsMenu();
          $this->add(&$p_object);

          // ----- Looking for action type
          PwsTraceFctMessage(__FILE__, __LINE__, 2, "Action type is '".$attrs['TYPE']."'");
          if ($attrs['TYPE']=='document_list')
          {
            $p_object->setAttribute(PWS_MENU_ATTRIBUTE_TYPE, PWS_MENU_TYPE_DOCUMENT_LIST);
          }

          // ----- Set the object & methods for the xml parser
          xml_set_object($p_parser, &$p_object);
        break;

        default :
          PwsTraceFctMessage(__FILE__, __LINE__, 2, "Unsupported token for this object");
          die("Unsupported token '$p_name' for MENU object");
      }

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : finishXmlToken()
    // Description :
    // --------------------------------------------------------------------------------
    function finishXmlToken($p_parser, $p_name)
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsMenu['.$this->id.']::finishXmlToken', "name='$p_name'");

      // ----- Look for token name
      switch ($p_name)
      {
        case "MENU" :
          PwsTraceFctMessage(__FILE__, __LINE__, 2, "End of PwsMenu object reading");

          // ----- Set the reference object back to the parent
          xml_set_object($p_parser, &$this->parent);

          // ----- Reset the working data
          $this->working_data = $p_name;
        break;
        default :
          PwsTraceFctMessage(__FILE__, __LINE__, 2, "Unsupported token for this object");
      }

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : readXmlTokenContent()
    // Description :
    // --------------------------------------------------------------------------------
    function readXmlTokenContent($p_parser, $p_data)
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsMenu['.$this->id.']::readXmlTokenContent', "data='$p_data'");

      // ----- Look for object type
      /*
      switch ($this->working_data)
      {
//        case "VALUE" :
//          if ($p_data != "")
//          {
//            PwsTraceFctMessage(__FILE__, __LINE__, 2, "Setting attribute ".$this->working_data." to '".$p_data."'");
//            $this->setAttribute('PWS_MENU_ATTRIBUTE_'.$this->working_data, $p_data);
//          }
//        break;
        default :
          ;
      }
      */

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : pAttach()
    // Description :
    // --------------------------------------------------------------------------------
    function pAttach($p_parent, $p_index=-1)
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsMenu['.$this->id.']::pAttach', "index=$p_index");

      // ----- Add a child
      $this->parent = &$p_parent;

      // ----- Check specific actions
      if (get_class($p_parent) == 'pwsbutton')
      {
        PwsTraceFctMessage(__FILE__, __LINE__, 2, "Parent is a button, so menu is a popup");
        $this->type = PWS_MENU_TYPE_POPUP;
      }

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : event_pws_pre_display()
    // Description :
    // --------------------------------------------------------------------------------
    function event_pws_pre_display(&$p_event)
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsMenu::event_pws_pre_display', "");

      // ----- Look if it is a Popup menu
      if ($this->type == PWS_MENU_TYPE_POPUP)
      {
        PwsTraceFctMessage(__FILE__, __LINE__, 2, "Displaying a popup menu");

//<div id='MenuPopup-<? echo  $this->id; ? >' style='position:absolute; left:100px; top:100px; z-index:100; visibility:hidden; background-color: #000000; layer-background-color: #000000; border: 1px none #000000'>
?>
<div id='MenuPopup-<? echo  $this->id; ?>' class="menuPopup">
<?php
        // ----- Create a generic frame
        //$v_frame = new PwsFrame();
        //$v_frame->setAttribute('PWS_FRAME_ATTRIBUTE_TYPE', PWS_FRAME_TYPE_POPUP);
        //$v_frame->setAttribute('PWS_FRAME_ATTRIBUTE_SIZE', PWS_FRAME_SIZE_BEST);
        //$v_frame->pDisplayHeader();

        // ----- Display the buttons
/*? >
<table border="0" cellspacing="0" cellpadding="0" bgcolor="#CCCCCC" name="MenuToolbar">
<?php
*/
        // ----- Display the buttons
        for ($i=0; $i<sizeof($this->childs); $i++)
        {
        /*
? >
  <tr bgcolor="#CCCCCC">
    <td height="1" width="4" bgcolor="#CCCCCC"></td>
    <td height="1" bgcolor="#CCCCCC">
      <font face="Arial, Helvetica, sans-serif" size="2">
<?php
*/
          $this->childs[$i]->event_pws_display($p_event);
/*
? >
      </font></td>
    <td height="1" bgcolor="#CCCCCC" width="4"></td>
  </tr>
<?php
*/
        }

/*
? >
      </table>
<?php
*/
        // ----- Display the application frame footer
        //$v_frame->pDisplayFooter();

?>
</div>
<?php
      }

      // ----- Display the childs objects
      PwsObjectGraphical::event_pws_pre_display($p_event);

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : event_pws_display()
    // Description :
    // --------------------------------------------------------------------------------
    function event_pws_display(&$p_event)
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsMenu::event_pws_display', "");

      // ----- Look for horizontal menu
      if ($this->type == PWS_MENU_TYPE_TOOLBAR)
      {
        PwsTraceFctMessage(__FILE__, __LINE__, 2, "Displaying a tool bar menu");

        // ----- Display the Menu toolbar beginning
?>
<div class="menuBar">
<?php
/*
<table border="0" cellspacing="0" cellpadding="0" bgcolor="#CCCCCC" name="MenuToolbar">
  <tr bgcolor="#CCCCCC">
    <td height="1" width="4" bgcolor="#CCCCCC"></td>
*/
?>
<?php
/*
    <td height="1" width="4" bgcolor="#CCCCCC"></td>
    <td height="1" width="10" bgcolor="#CCCCCC"></td>
    <td height="1" width="1" bgcolor="#CCCCCC"><font face="Arial, Helvetica, sans-serif" size="2">Edit</font></td>
    <td height="1" width="10" bgcolor="#CCCCCC"></td>
    <td height="1" width="1" bgcolor="#CCCCCC"><font face="Arial, Helvetica, sans-serif" size="2">View</font></td>
    <td height="1" width="10" bgcolor="#CCCCCC"></td>
    <td height="1" width="1" bgcolor="#CCCCCC"><font face="Arial, Helvetica, sans-serif" size="2">Help</font></td>
*/
      // ----- Display the childs graphical objects
      if (($nb=sizeof($this->childs))!=0)
      {
        for ($i=0; $i<$nb; $i++)
        {
//    <td height="1" width="4" bgcolor="#CCCCCC"></td>
?>
<?php
/*
    <td height="1" bgcolor="#CCCCCC">
*/
?>
<?php
          $this->childs[$i]->event_pws_display($p_event);
?>
<?php
/*
    </td>
*/
?>
<?php
        }
      }
      else
      {
?>
<?php
      }

      // ----- Display the menu toolbar ending
?>
<?php
/*
    <td height="1" bgcolor="#CCCCCC">&nbsp;</td>
  </tr>
</table>
*/
?>
</div>

<?php
      }
      // ----- Look for vertical menu
      else if ($this->type == PWS_MENU_TYPE_POPUP)
      {
        PwsTraceFctMessage(__FILE__, __LINE__, 2, "The menu is a popup, nothing to display");
      }
      // ----- Look for vertical menu
      else if ($this->type == PWS_MENU_TYPE_DOCUMENT_LIST)
      {
        PwsTraceFctMessage(__FILE__, __LINE__, 2, "Displayig a document list");

        global $pws_application;

        // ----- Get the document list
        $v_min = min(sizeof($pws_application->documents), 10);
        for ($i=0;$i<$v_min;$i++)
        {
          // ----- Get the 'url' to be used for this event
          $v_url = PwsComposeJavaEvent('pws_select_document', $this, '',
                                       'document', $pws_application->documents[$i]->id);

          echo "<a href='javascript:void();' ";
          echo "onClick='".$v_url."'; return false; ";
          echo "class='menuPopupButton'>";
          echo ($i+1)."- ".$pws_application->documents[$i]->name;
          echo "</a>\n";
        }
      }

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

  }
  // End of class
  // --------------------------------------------------------------------------------


?>
