<?
// --------------------------------------------------------------------------------
// PhpWindowSystem - PwsModule Class
// --------------------------------------------------------------------------------
//
// Presentation :
//   PhpWindowSystem is a generic PHP window system management.
//   PhpWindowSystem is designed to take care of window displaying and
//   manage the associated events in order to offer a generic application
//   container.
//   More information can be obtained on
//   PhpConcept (http://www.phpconcept.net)
//   or by contacting the author Vincent Blavet (vincent@phpconcept.net)
//
// --------------------------------------------------------------------------------
// License :
//   PhpWindowSystem (PWS)
//   Copyright (C) 2002  Vincent Blavet (vincent@phpconcept.net)
//
//   This library is free software; you can redistribute it and/or
//   modify it under the terms of the GNU Lesser General Public
//   License as published by the Free Software Foundation; either
//   version 2.1 of the License, or (at your option) any later version.
//
//   This library is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//   Lesser General Public License for more details.
//
//   You should have received a copy of the GNU Lesser General Public
//   License along with this library; if not, write to the Free Software
//   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// --------------------------------------------------------------------------------
// CVS : $Id: pws-module.class.php,v 1.1 2002/08/26 22:07:43 vblavet Exp $
// --------------------------------------------------------------------------------

  // ----- Class objects
  require_once('pws/core/pws-object-graphical.class.php');

  // ----- Class ID
  define ('PWS_MODULE_ID', 10120000);

  // ----- Action types
  define ('PWS_MODULE_ATTRIBUTE_NAME', PWS_MODULE_ID+1);
  define ('PWS_MODULE_ATTRIBUTE_VERSION', PWS_MODULE_ID+2);
  define ('PWS_MODULE_ATTRIBUTE_LINK', PWS_MODULE_ID+3);
  define ('PWS_MODULE_ATTRIBUTE_DESCRIPTION', PWS_MODULE_ID+4);

  // --------------------------------------------------------------------------------
  // Class : PwsModule
  // Description :
  // Attributes :
  // --------------------------------------------------------------------------------
  class PwsModule extends PwsObjectGraphical
  {
    // ----- Object attributes
    var $name='';
    var $version='';
    var $link='';
    var $description='';

    // --------------------------------------------------------------------------------
    // Method : PwsModule()
    // Description :
    //   Constructor
    // --------------------------------------------------------------------------------
    function PwsModule()
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsModule::PwsModule', "");

      // ----- Call the Parent constructor
      PwsObjectGraphical::PwsObjectGraphical();

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : pSetSingleAttribute()
    // Description :
    // --------------------------------------------------------------------------------
    function pSetSingleAttribute($p_name, $p_value)
    {
      $v_result=1;
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsModule['.$this->id.']::pSetSingleAttribute', "name='$p_name', value='$p_value'");

      // ----- Look first for parent class attribute
      if (($v_result = PwsObjectGraphical::pSetSingleAttribute($p_name, $p_value)) == 0) {
        // ----- Set the attribute
        switch ($p_name)
        {
          case PWS_MODULE_ATTRIBUTE_NAME :
            $this->name = $p_value;
          break;

          case PWS_MODULE_ATTRIBUTE_VERSION :
            $this->version = $p_value;
          break;

          case PWS_MODULE_ATTRIBUTE_LINK :
            $this->link = $p_value;
          break;

          case PWS_MODULE_ATTRIBUTE_DESCRIPTION :
            $this->description = $p_value;
          break;

          default :
            PwsTraceFctMessage(__FILE__, __LINE__, 2, "Unknown attribute '$p_name' for PwsModule object");
            $v_result=0;
        }
      }

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, $v_result);
      return $v_result;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : readXmlToken()
    // Description :
    // --------------------------------------------------------------------------------
    function readXmlToken($p_parser, $p_name, $attrs)
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsModule['.$this->id.']::readXmlToken', "name='$p_name'");

      // ----- Look for token name
      switch ($p_name)
      {
      /*
        case "CHILD" :
          PwsTraceFctMessage(__FILE__, __LINE__, 2, "Found token CHILD, create object");

          // ----- Create a new Title object
          $p_object = new PwsFrame();
          $this->add(&$p_object);

          // ----- Set the object & methods for the xml parser
          xml_set_object($p_parser, &$p_object);
        break;

        case "ATTRIBUT" :
          $this->working_data = $p_name;
        break;
        */

        default :
          PwsTraceFctMessage(__FILE__, __LINE__, 2, "Unsupported token for this object");
          die("Unsupported token '$p_name' for PwsModule object (".__FILE__.", ".__LINE__.")");

      }

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : readXmlAttributs()
    // Description :
    // --------------------------------------------------------------------------------
    function readXmlAttributs($attrs)
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsModule['.$this->id.']::readXmlAttributs', "");

      if (isset($attrs['NAME']))
      {
        PwsTraceFctMessage(__FILE__, __LINE__, 2, "Module name is '".$attrs['NAME']."'");
        $this->setAttribute(PWS_MODULE_ATTRIBUTE_NAME, $attrs['NAME']);
      }

      if (isset($attrs['VERSION']))
      {
        PwsTraceFctMessage(__FILE__, __LINE__, 2, "Module version is '".$attrs['VERSION']."'");
        $this->setAttribute(PWS_MODULE_ATTRIBUTE_VERSION, $attrs['VERSION']);
      }

      if (isset($attrs['LINK']))
      {
        PwsTraceFctMessage(__FILE__, __LINE__, 2, "Module link is '".$attrs['LINK']."'");
        $this->setAttribute(PWS_MODULE_ATTRIBUTE_LINK, $attrs['LINK']);
      }

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : finishXmlToken()
    // Description :
    // --------------------------------------------------------------------------------
    function finishXmlToken($p_parser, $p_name)
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsModule['.$this->id.']::finishXmlToken', "name='$p_name'");

      // ----- Look for token name
      switch ($p_name)
      {
        case "MODULE" :
          PwsTraceFctMessage(__FILE__, __LINE__, 2, "End of PwsModule object reading");

          // ----- Set the reference object back to the parent
          xml_set_object($p_parser, &$this->parent);

          // ----- Reset the working data
          $this->working_data = $p_name;
        break;
        default :
          PwsTraceFctMessage(__FILE__, __LINE__, 2, "Unsupported token for this object");
          die("Unsupported finishing token '$p_name' for PwsModule object (".__FILE__.", ".__LINE__.")");
      }

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : readXmlTokenContent()
    // Description :
    // --------------------------------------------------------------------------------
    function readXmlTokenContent($p_parser, $p_data)
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsModule['.$this->id.']::readXmlTokenContent', "data='$p_data'");

      // ----- Add the text in the description
      $this->description .= trim($p_data);

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : event_pws_display()
    // Description :
    // --------------------------------------------------------------------------------
    function event_pws_display(&$p_event)
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsModule['.$this->id.']::event_pws_display', "");

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

  }
  // End of class
  // --------------------------------------------------------------------------------


?>
