<?
// --------------------------------------------------------------------------------
// PhpWindowSystem - PwsObject Class
// --------------------------------------------------------------------------------
//
// Presentation :
//   PhpWindowSystem is a generic PHP window system management.
//   PhpWindowSystem is designed to take care of window displaying and
//   manage the associated events in order to offer a generic application
//   container.
//   More information can be obtained on
//   PhpConcept (http://www.phpconcept.net)
//   or by contacting the author Vincent Blavet (vincent@phpconcept.net)
//
// --------------------------------------------------------------------------------
// License :
//   PhpWindowSystem (PWS)
//   Copyright (C) 2002  Vincent Blavet (vincent@phpconcept.net)
//
//   This library is free software; you can redistribute it and/or
//   modify it under the terms of the GNU Lesser General Public
//   License as published by the Free Software Foundation; either
//   version 2.1 of the License, or (at your option) any later version.
//
//   This library is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//   Lesser General Public License for more details.
//
//   You should have received a copy of the GNU Lesser General Public
//   License along with this library; if not, write to the Free Software
//   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// --------------------------------------------------------------------------------
// CVS : $Id: pws-object.class.php,v 1.1 2002/08/26 22:07:43 vblavet Exp $
// --------------------------------------------------------------------------------

  // ----- Libraries
  require_once('pws/core/pws-trace.lib.php');

  // ----- Class ID
  define ('PWS_OBJECT_ID', 10010000);
  define ('PWS_DISPLAY_OBJECT_ID', 10010100);

  // ----- Define constants

  // --------------------------------------------------------------------------------
  // Class : PwsObject
  // Description :
  // Attributes :
  // --------------------------------------------------------------------------------
  class PwsObject
  {
    // ----- Working data
    // These attributes are only used while reading the xml file
    // should be modified and removed from the object
    var $working_data;
    var $working_attributs;

    // --------------------------------------------------------------------------------
    // Method : PwsObject()
    // Description :
    //   Constructor
    // --------------------------------------------------------------------------------
    function PwsObject()
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsObject::PwsObject', "");

      // ----- Initialize
      //$this->id = PwsGetId();

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : setAttribute()
    // Description :
    // --------------------------------------------------------------------------------
    function setAttribute($p_name, $p_value /*, $p_name, $p_value, ... */)
    {
      $v_result = 1;
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsObject['.$this->id.']::setAttribute', "name='$p_name', value='$p_value', ...");

      // ----- Set the first couple of attributes
      $v_result = $this->pSetSingleAttribute($p_name, $p_value);

      // ----- Look for other optional attributes
      if ($v_result == 1) {
        // ----- Get the number of args
        $v_nb_args = func_num_args();
        PwsTraceFctMessage(__FILE__, __LINE__, 5, "$v_nb_args arguments");

        // ----- Read each couples
        for ($i=2; ($i<$v_nb_args) && (($i+1)<$v_nb_args) && ($v_result==1); $i += 2) {
          $v_name = func_get_arg($i);
          PwsTraceFctMessage(__FILE__, __LINE__, 5, "Attribute name is '".$v_name."'");
          $v_value = func_get_arg($i+1);
          PwsTraceFctMessage(__FILE__, __LINE__, 5, "Attribute value is '".$v_value."'");
          $v_result = $this->pSetSingleAttribute($v_name, $v_value);
        }
      }

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, $v_result);
      return $v_result;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : pSetSingleAttribute()
    // Description :
    // --------------------------------------------------------------------------------
    function pSetSingleAttribute($p_name, $p_value)
    {
      $v_result=1;
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsObject['.$this->id.']::pSetSingleAttribute', "name='$p_name', value='$p_value'");

      // ----- Set the attribute
      switch ($p_name)
      {
        default :
          PwsTraceFctMessage(__FILE__, __LINE__, 2, "Unknown attribute '$p_name' for this object");
          $v_result=0;
      }

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, $v_result);
      return $v_result;
    }
    // --------------------------------------------------------------------------------

  }
  // End of class
  // --------------------------------------------------------------------------------

/*
  // --------------------------------------------------------------------------------
  // Class : PwsDisplayObject
  // Description :
  // Attributes :
  // --------------------------------------------------------------------------------
  class PwsDisplayObject extends PwsObject
  {
    // ----- Unic id
    var $id;

    // ----- Callbacks attached to object
    var $actions;

    // ----- Application (graphical) parent
    var $parent;

    // ----- Application (graphical) childs
    var $childs;

    // ----- Working data
    // These attributes are only used while reading the xml file
    // should be modified and removed from the object
    var $working_data;
    var $working_attributs;

    // --------------------------------------------------------------------------------
    // Method : PwsObject()
    // Description :
    //   Constructor
    // --------------------------------------------------------------------------------
    function PwsDisplayObject()
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsDisplayObject::PwsDisplayObject', "");

      // ----- Call the super class constructor
      PwsObject::PwsObject();

      // ----- Initialize
      $this->id = PwsGetId();
      $this->childs = array();
      $this->actions = array();
      $this->parent = 0;

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : pSetSingleAttribute()
    // Description :
    // --------------------------------------------------------------------------------
    function pSetSingleAttribute($p_name, $p_value)
    {
      $v_result=1;
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsDisplayObject['.$this->id.']::pSetSingleAttribute', "name='$p_name', value='$p_value'");

      // ----- Look first for parent class attribute
      if (($v_result = PwsObject::pSetSingleAttribute($p_name, $p_value)) == 0) {
        // ----- Set the attribute
        switch ($p_name)
        {
          default :
            PwsTraceFctMessage(__FILE__, __LINE__, 2, "Unknown attribute '$p_name' for PwsDisplayObject object");
            $v_result=0;
        }
      }

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, $v_result);
      return $v_result;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : isWindow()
    // Description :
    // --------------------------------------------------------------------------------
    function isWindow()
    {
      $v_result=0;
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsDisplayObject['.$this->id.']::isWindow', "");

      PwsTraceFctMessage(__FILE__, __LINE__, 2, "Object class='".get_class($this)."'");
      PwsTraceFctMessage(__FILE__, __LINE__, 2, "Sub class ?'".is_subclass_of($this, 'pwswindow')."'");

      // ------ Look if the object is a window or is from an inheriting class
      if ((get_class($this) == 'pwswindow') || (is_subclass_of($this, 'pwswindow'))) {
        $v_result=1;
      }

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, $v_result);
      return $v_result;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : getParentWindow()
    // Description :
    // --------------------------------------------------------------------------------
    function & getParentWindow()
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsDisplayObject['.$this->id.']::getParentWindow', "");

      if ($this->isWindow())
      {
        $v_result = & $this;
      }
      else if (is_object($this->parent))
      {
        $v_result = & $this->parent->getParentWindow();
      }
      else
      {
        PwsTraceFctMessage(__FILE__, __LINE__, 2, "Warning : Parent window not found. All graphical object should have a window parent.");
        $v_result = 0;
      }

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, $v_result);
      return $v_result;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : getParent()
    // Description :
    // --------------------------------------------------------------------------------
    function &getParent($p_classname='')
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsDisplayObject['.$this->id.']::getParent', "classname='$p_classname'");

      // ----- Check specific classname
      if ($p_classname == '') {
        PwsTraceFctMessage(__FILE__, __LINE__, 2, "Return direct parent");
        $v_parent = &$this->parent;
      }
      else {
        PwsTraceFctMessage(__FILE__, __LINE__, 2, "Check parent class");
        // ----- Look the parent class
        if (get_class($this->parent) == $p_classname) {
          PwsTraceFctMessage(__FILE__, __LINE__, 2, "Direct parent class match");
          $v_parent = &$this->parent;
        }
        else {
          if (is_object($this->parent)) {
            PwsTraceFctMessage(__FILE__, __LINE__, 2, "Look for parent of parent");
            $v_parent = & $this->parent->getParent($p_classname);
          }
          else {
            PwsTraceFctMessage(__FILE__, __LINE__, 2, "No valid parent");
            $v_parent = 0;
          }
        }
      }

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, $v_parent);
      return $v_parent;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : start()
    // Description :
    // --------------------------------------------------------------------------------
    function start()
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsDisplayObject['.$this->id.']::start', "");

      // ----- Init all the childs
      if (($nb=sizeof($this->childs))!=0)
      {
        for ($i=0; $i<$nb; $i++)
        {
          $this->childs[$i]->start();
        }
      }

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : add()
    // Description :
    // --------------------------------------------------------------------------------
    function add(&$p_child, $p_index=-1)
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsDisplayObject['.$this->id.']::add', "child='".$p_child->id."', index=$p_index");

      // ----- Add a child
      $nb = sizeof($this->childs);
      PwsTraceFctMessage(__FILE__, __LINE__, 2, "Adding child at index $nb");
      $this->childs[$nb] = &$p_child;
      $p_child->pAttach(&$this, $p_index);

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------


    // --------------------------------------------------------------------------------
    // Method : receiveEvent()
    // Description :
    // --------------------------------------------------------------------------------
    function receiveEvent(&$p_event)
    {
      $v_result = 1;
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsDisplayObject['.$this->id.']::receiveEvent', "");

      PwsTraceFctMessage(__FILE__, __LINE__, 2, "Receiving event : '".$p_event->event."'");

      // ----- Calling the generic event method associated to the event
//      $v_eval = "\$v_result=\$this->event_".$p_event->event."(\$p_event);";
//      PwsTraceFctMessage(__FILE__, __LINE__, 2, "Doing eval of : '".$v_eval."'");
//      eval($v_eval);
      $v_result = call_user_method('event_'.$p_event->event, $this, $p_event);

      // ----- Send the event to all the childs but not for diplay events
      if (   ($p_event->event != 'pws_display')
          && ($p_event->event != 'pws_pre_display')
          && ($p_event->event != 'pws_post_display'))
      {
        if (($nb=sizeof($this->childs))!=0)
        {
          for ($i=0; $i<$nb; $i++)
          {
            $this->childs[$i]->receiveEvent($p_event);
          }
        }
      }

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : pAttach()
    // Description :
    // --------------------------------------------------------------------------------
    function pAttach($p_parent, $p_index=-1)
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsDisplayObject['.$this->id.']::pAttach', "parent='".$p_parent->id."', index=$p_index");

      // ----- Add a child
      $this->parent = &$p_parent;

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : event_pws_header_display()
    // Description :
    //   TBC : Futur use .... to be able to add HTML lines in <header> token
    // --------------------------------------------------------------------------------
    function event_pws_header_display(&$p_event)
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsDisplayObject['.$this->id.']::event_pws_header_display', "");

      // ----- Display the childs graphical objects
      if (($nb=sizeof($this->childs))!=0)
      {
        for ($i=0; $i<$nb; $i++)
        {
          $this->childs[$i]->event_pws_header_display($p_event);
        }
      }

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : event_pws_style_display()
    // Description :
    //   TBC : Futur use .... to be able to add style in <header> token
    // --------------------------------------------------------------------------------
    function event_pws_style_display(&$p_event)
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsDisplayObject['.$this->id.']::event_pws_style_display', "");

      // ----- Display the childs graphical objects
      if (($nb=sizeof($this->childs))!=0)
      {
        for ($i=0; $i<$nb; $i++)
        {
          $this->childs[$i]->event_pws_style_display($p_event);
        }
      }

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : event_pws_script_display()
    // Description :
    //   TBC : Futur use .... to be able to add <script> at the beginning of <body>
    //         token
    // --------------------------------------------------------------------------------
    function event_pws_script_display(&$p_event)
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsDisplayObject['.$this->id.']::event_pws_script_display', "");

      // ----- Display the childs graphical objects
      if (($nb=sizeof($this->childs))!=0)
      {
        for ($i=0; $i<$nb; $i++)
        {
          $this->childs[$i]->event_pws_script_display($p_event);
        }
      }

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : event_pws_pre_display()
    // Description :
    // --------------------------------------------------------------------------------
    function event_pws_pre_display(&$p_event)
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsDisplayObject['.$this->id.']::event_pws_pre_display', "");

      // ----- Display the childs graphical objects
      if (($nb=sizeof($this->childs))!=0)
      {
        for ($i=0; $i<$nb; $i++)
        {
          $this->childs[$i]->event_pws_pre_display($p_event);
        }
      }

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : event_pws_display()
    // Description :
    // --------------------------------------------------------------------------------
    function event_pws_display(&$p_event)
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsDisplayObject['.$this->id.']::event_pws_display', "");

      // ----- Commentaries
      // This method must be overcharged by a consistent object display

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : event_pws_post_display()
    // Description :
    // --------------------------------------------------------------------------------
    function event_pws_post_display(&$p_event)
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsDisplayObject['.$this->id.']::event_pws_post_display', "");

      // ----- Display the childs graphical objects
      if (($nb=sizeof($this->childs))!=0)
      {
        for ($i=0; $i<$nb; $i++)
        {
          $this->childs[$i]->event_pws_post_display($p_event);
        }
      }

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

  }
  // End of class
  // --------------------------------------------------------------------------------

  // --------------------------------------------------------------------------------
  // Method : PwsGetId()
  // Description :
  // --------------------------------------------------------------------------------
  function PwsGetId()
  {
  //  global $pws_count;
    global $pws_application;

    PwsTraceFctStart(__FILE__, __LINE__, 'PwsGetId', "");

//    $pws_count++;
    $v_result = $pws_application->generateId();

    // ----- Return
    PwsTraceFctEnd(__FILE__, __LINE__, $v_result);
    return $v_result;
  }
  // --------------------------------------------------------------------------------
*/

?>
