<?
// --------------------------------------------------------------------------------
// PhpWindowSystem - PwsSeparator Class
// --------------------------------------------------------------------------------
//
// Presentation :
//   PhpWindowSystem is a generic PHP window system management.
//   PhpWindowSystem is designed to take care of window displaying and
//   manage the associated events in order to offer a generic application
//   container.
//   More information can be obtained on
//   PhpConcept (http://www.phpconcept.net)
//   or by contacting the author Vincent Blavet (vincent@phpconcept.net)
//
// --------------------------------------------------------------------------------
// License :
//   PhpWindowSystem (PWS)
//   Copyright (C) 2002  Vincent Blavet (vincent@phpconcept.net)
//
//   This library is free software; you can redistribute it and/or
//   modify it under the terms of the GNU Lesser General Public
//   License as published by the Free Software Foundation; either
//   version 2.1 of the License, or (at your option) any later version.
//
//   This library is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//   Lesser General Public License for more details.
//
//   You should have received a copy of the GNU Lesser General Public
//   License along with this library; if not, write to the Free Software
//   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// --------------------------------------------------------------------------------
// CVS : $Id: pws-separator.class.php,v 1.1 2002/08/26 22:07:43 vblavet Exp $
// --------------------------------------------------------------------------------

  // ----- Class objects
  require_once('pws/core/pws-object-graphical.class.php');

  // ----- Define objects classes
  define ("PWS_SEPARATOR_TYPE_HORIZONTAL", 0);
  define ("PWS_SEPARATOR_TYPE_VERTICAL", 1);

  // ----- Class ID
  define ('PWS_SEPARATOR_ID', 10090000);

  // ----- Attributes definition
  define ('PWS_SEPARATOR_ATTRIBUTE_TYPE', PWS_SEPARATOR_ID+1);

  // --------------------------------------------------------------------------------
  // Class : PwsSeparator
  // Description :
  // Attributes :
  // --------------------------------------------------------------------------------
  class PwsSeparator extends PwsObjectGraphical
  {
    // ----- Object attributes
    var $type;

    // --------------------------------------------------------------------------------
    // Method : PwsSeparator()
    // Description :
    //   Constructor
    // --------------------------------------------------------------------------------
    function PwsSeparator()
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsSeparator::PwsSeparator', "");

      // ----- Call the Parent constructor
      PwsObjectGraphical::PwsObjectGraphical();

      // ----- Initialize
      $this->type = PWS_SEPARATOR_TYPE_HORIZONTAL;

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : pSetSingleAttribute()
    // Description :
    // --------------------------------------------------------------------------------
    function pSetSingleAttribute($p_name, $p_value)
    {
      $v_result=1;
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsSeparator['.$this->id.']::pSetSingleAttribute', "name='$p_name', value='$p_value'");

      // ----- Look first for parent class attribute
      if (($v_result = PwsObjectGraphical::pSetSingleAttribute($p_name, $p_value)) == 0) {
        // ----- Set the attribute
        switch ($p_name)
        {
          case PWS_SEPARATOR_ATTRIBUTE_TYPE :
            $this->type = $p_value;
          break;
          default :
            PwsTraceFctMessage(__FILE__, __LINE__, 2, "Unknown attribute '$p_name' for PwsSeparator object");
            $v_result=0;
        }
      }

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, $v_result);
      return $v_result;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : readXmlToken()
    // Description :
    // --------------------------------------------------------------------------------
    function readXmlToken($p_parser, $p_name, $attrs)
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsSeparator::readXmlToken', "name='$p_name'");

      // ----- Look for token name
      switch ($p_name)
      {
        case "TYPE" :
          $this->working_data = $p_name;
        break;
        default :
          PwsTraceFctMessage(__FILE__, __LINE__, 2, "Unsupported token for this object");
          die("Unsupported token '$p_name' for SEPARATOR object");
      }

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : finishXmlToken()
    // Description :
    // --------------------------------------------------------------------------------
    function finishXmlToken($p_parser, $p_name)
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsSeparator::finishXmlToken', "name='$p_name'");

      // ----- Look for token name
      switch ($p_name)
      {
        case "SEPARATOR" :
          PwsTraceFctMessage(__FILE__, __LINE__, 2, "End of PwsSeparator object reading");

          // ----- Set the reference object back to the parent
          xml_set_object($p_parser, &$this->parent);

          // ----- Reset the working data
          $this->working_data = $p_name;
        break;
        case "TYPE" :
          PwsTraceFctMessage(__FILE__, __LINE__, 2, "End of attribute data, reset working data");
          $this->working_data = '';
        break;
        default :
          PwsTraceFctMessage(__FILE__, __LINE__, 2, "Unsupported token for this object");
      }

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : readXmlTokenContent()
    // Description :
    // --------------------------------------------------------------------------------
    function readXmlTokenContent($p_parser, $p_data)
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsSeparator::readXmlTokenContent', "data='$p_data'");

      // ----- Look for object type
      switch ($this->working_data)
      {
        case "TYPE" :
          if ($p_data != "")
          {
            PwsTraceFctMessage(__FILE__, __LINE__, 2, "Setting attribute ".$this->working_data." to '".$p_data."'");
            $this->setAttribute(PWS_SEPARATOR_ATTRIBUTE_TYPE, $p_data);
          }
        break;
        default :
          ;
      }

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : event_pws_display()
    // Description :
    // --------------------------------------------------------------------------------
    function event_pws_display(&$p_event)
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsSeparator::event_pws_display', "");

      // ----- Look the type
      if ($this->type == PWS_SEPARATOR_TYPE_HORIZONTAL)
      {
?>
<div class="separatorHorizontal"></div>
<?php
/*
<table width="100%" border="0" cellspacing="0" cellpadding="0" bgcolor="#CCCCCC" name="SeparatorHoriz">
  <tr>
    <td height="1" bgcolor="#CCCCCC"></td>
  </tr>
  <tr>
    <td height="1" bgcolor="#333333"></td>
  </tr>
  <tr>
    <td height="1" bgcolor="#FFFFFF">
  </tr>
  <tr>
    <td height="1" bgcolor="#CCCCCC">
  </tr>
</table>
*/
      }
      else
      {
?>
<table height="100%" border="0" cellspacing="0" cellpadding="0" bgcolor="#CCCCCC" name="SeparatorVert">
  <tr>
    <td width="1" bgcolor="#CCCCCC"></td>
    <td width="1" bgcolor="#333333"></td>
    <td width="1" bgcolor="#FFFFFF"></td>
    <td width="1" bgcolor="#CCCCCC"></td>
  </tr>
</table>

<?php
      }

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

  }
  // End of class
  // --------------------------------------------------------------------------------


?>
