<?
// --------------------------------------------------------------------------------
// PhpWindowSystem - PwsTitle Class
// --------------------------------------------------------------------------------
//
// Presentation :
//   PhpWindowSystem is a generic PHP window system management.
//   PhpWindowSystem is designed to take care of window displaying and
//   manage the associated events in order to offer a generic application
//   container.
//   More information can be obtained on
//   PhpConcept (http://www.phpconcept.net)
//   or by contacting the author Vincent Blavet (vincent@phpconcept.net)
//
// --------------------------------------------------------------------------------
// License :
//   PhpWindowSystem (PWS)
//   Copyright (C) 2002  Vincent Blavet (vincent@phpconcept.net)
//
//   This library is free software; you can redistribute it and/or
//   modify it under the terms of the GNU Lesser General Public
//   License as published by the Free Software Foundation; either
//   version 2.1 of the License, or (at your option) any later version.
//
//   This library is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//   Lesser General Public License for more details.
//
//   You should have received a copy of the GNU Lesser General Public
//   License along with this library; if not, write to the Free Software
//   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// --------------------------------------------------------------------------------
// CVS : $Id: pws-title.class.php,v 1.1 2002/08/26 22:07:43 vblavet Exp $
// --------------------------------------------------------------------------------

  // ----- Class objects
  require_once('pws/core/pws-object-graphical.class.php');

  // ----- Class ID
  define ('PWS_TITLE_ID', 10040000);

  // ----- Attributes definition
  define ('PWS_TITLE_ATTRIBUTE_NAME', PWS_TITLE_ID+1);
  define ('PWS_TITLE_ATTRIBUTE_ICON', PWS_TITLE_ID+2);

  // --------------------------------------------------------------------------------
  // Class : PwsTitle
  // Description :
  // Attributes :
  // --------------------------------------------------------------------------------
  class PwsTitle extends PwsObjectGraphical
  {
    // ----- Object attributes
    var $name;
    var $icon;

    // --------------------------------------------------------------------------------
    // Method : PwsTitle()
    // Description :
    //   Constructor
    // --------------------------------------------------------------------------------
    function PwsTitle()
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsTitle::PwsTitle', "");

      // ----- Call the Parent constructor
      PwsObjectGraphical::PwsObjectGraphical();

      // ----- Initialize

      // TBC : Should be a configurable value
      $this->icon = ''; //'pws/core/images/icon-default.gif';

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : pSetSingleAttribute()
    // Description :
    // --------------------------------------------------------------------------------
    function pSetSingleAttribute($p_name, $p_value)
    {
      $v_result=1;
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsTitle['.$this->id.']::pSetSingleAttribute', "name='$p_name', value='$p_value'");

      // ----- Look first for parent class attribute
      if (($v_result = PwsObjectGraphical::pSetSingleAttribute($p_name, $p_value)) == 0) {
        // ----- Set the attribute
        switch ($p_name)
        {
          case PWS_TITLE_ATTRIBUTE_NAME :
            $this->name = $p_value;
          break;
          case PWS_TITLE_ATTRIBUTE_ICON :
            $this->icon = $p_value;
          break;
          default :
            PwsTraceFctMessage(__FILE__, __LINE__, 2, "Unknown attribute '$p_name' for PwsTitle object");
            $v_result=0;
        }
      }

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, $v_result);
      return $v_result;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : readXmlToken()
    // Description :
    // --------------------------------------------------------------------------------
    function readXmlToken($p_parser, $p_name, $attrs)
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsTitle::readXmlToken', "name='$p_name'");

      // ----- Look for token name
      switch ($p_name)
      {
        case "NAME" :
        case "ICON" :
          $this->working_data = $p_name;
        break;
        default :
          PwsTraceFctMessage(__FILE__, __LINE__, 2, "Unsupported token for this object");
          die("Unsupported token '$p_name' for TITLE object");

      }

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : finishXmlToken()
    // Description :
    // --------------------------------------------------------------------------------
    function finishXmlToken($p_parser, $p_name)
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsTitle::finishXmlToken', "name='$p_name'");

      // ----- Look for token name
      switch ($p_name)
      {
        case "TITLE" :
          PwsTraceFctMessage(__FILE__, __LINE__, 2, "End of PwsTitle object reading");

          // ----- Set the reference object back to the parent
          xml_set_object($p_parser, &$this->parent);

          // ----- Reset the working data
          $this->working_data = $p_name;
        break;
        case "NAME" :
        case "ICON" :
          PwsTraceFctMessage(__FILE__, __LINE__, 2, "End of attribute data, reset working data");
          $this->working_data = '';
        break;
        default :
          PwsTraceFctMessage(__FILE__, __LINE__, 2, "Unsupported token for this object");
      }

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : readXmlTokenContent()
    // Description :
    // --------------------------------------------------------------------------------
    function readXmlTokenContent($p_parser, $p_data)
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsTitle::readXmlTokenContent', "data='$p_data'");

      // ----- Look for object type
      switch ($this->working_data)
      {
        case "NAME" :
        case "ICON" :
          if (trim($p_data) != "")
          {
            PwsTraceFctMessage(__FILE__, __LINE__, 2, "Setting attribute ".$this->working_data." to '".$p_data."'");
            eval('$this->setAttribute(PWS_TITLE_ATTRIBUTE_'.$this->working_data.', trim($p_data));');
          }
        break;
        default :
          ;
      }

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : pAttach()
    // Description :
    // --------------------------------------------------------------------------------
    function pAttach($p_parent, $p_index=-1)
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsTitle['.$this->id.']::pAttach', "parent='".$p_parent->class_type."', index=$p_index");

      // ----- Add a child
      $this->parent = &$p_parent;

      // ----- Get the PwsApplication parent
      $v_application = $this->getParent('pwsapplication');

      // ----- Check specific actions
      if (is_object($v_application))
      {
        PwsTraceFctMessage(__FILE__, __LINE__, 5, "Inherit application attributes (".$v_application->name.",".$v_application->version.",".$v_application->icon.")");
        $this->name = $v_application->name.' '.$v_application->version;
        $this->icon = $v_application->icon;
      }

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : event_pws_display()
    // Description :
    // --------------------------------------------------------------------------------
    function event_pws_display(&$p_event)
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsTitle::event_pws_display', "");

      // ----- Get the PwsApplication parent
      $v_application = $this->getParent('pwsapplication');

      // ----- Get current document
      if (($v_document = $v_application->getDocument()) != 0) {
        $v_document_name = $v_document->name;
      }
      else {
        $v_document_name = 'No Document';
      }

?>
<div class='titleBar'>
<span>
    <?php
      // ----- Look for a defined icon image
      // TBC : Should also check for the size of the image (16x16)
      if ($this->icon != "")
      {
        PwsTraceFctMessage(__FILE__, __LINE__, 5, 'Displaying specififc icon');
    ?>
      <img src="<?php echo $this->icon; ?>" width="16" height="16"  align="absmiddle">
    <?php
      }
      else
      {
    ?>
      <img src='<? echo PwsUtilImageSrc('icon-default.gif'); ?>' width="16" height="16" align="absmiddle">
      </img>
    <?php
      }
    ?>
<?php echo $this->name; ?>
 -
<?php

    // ----- Display document name
    echo $v_document_name;
/* TBC : At the begining I was thinking about adding theses icons ....
    <img src="images/minimize.jpg" width="16" height="14" align="absmiddle">
    <img src="images/fullscreen.jpg" width="16" height="14" align="absmiddle">
    <img src="images/close.jpg" width="16" height="14" align="absmiddle">
*/
?>
</span>
</div>
<?php
      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------


  }
  // End of class
  // --------------------------------------------------------------------------------


?>
