// --------------------------------------------------------------------------------
// PhpWindowSystem - Pws JavaScript Utilities
// --------------------------------------------------------------------------------
//
// Presentation :
//   PhpWindowSystem is a generic PHP window system management.
//   PhpWindowSystem is designed to take care of window displaying and
//   manage the associated events in order to offer a generic application
//   container.
//   More information can be obtained on
//   PhpConcept (http://www.phpconcept.net)
//   or by contacting the author Vincent Blavet (vincent@phpconcept.net)
//
// --------------------------------------------------------------------------------
// License :
//   PhpWindowSystem (PWS)
//   Copyright (C) 2002  Vincent Blavet (vincent@phpconcept.net)
//
//   This library is free software; you can redistribute it and/or
//   modify it under the terms of the GNU Lesser General Public
//   License as published by the Free Software Foundation; either
//   version 2.1 of the License, or (at your option) any later version.
//
//   This library is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//   Lesser General Public License for more details.
//
//   You should have received a copy of the GNU Lesser General Public
//   License along with this library; if not, write to the Free Software
//   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// --------------------------------------------------------------------------------
// CVS : $Id: pws-utilities.js.php,v 1.1 2002/08/26 22:07:43 vblavet Exp $
// --------------------------------------------------------------------------------

// --------------------------------------------------------------------------------
// Function : PwsGetAbsolutePosition()
// Description :
//   Get the absolute position of an object.
//   The function calculates the absolute position by adding all the relative
//   offset, from the object to the oldest parent.
// --------------------------------------------------------------------------------
function PwsGetAbsolutePosition(p_object)
{
  var v_left;
  var v_top;
  var v_position = {left:0,top:0};

  // ----- Get the object relative position
  v_position.left = p_object.offsetLeft;
  v_position.top = p_object.offsetTop;

  // ----- Get the parent absolute position
  if (p_object.offsetParent != null) {
    var v_parent_position = {left:0,top:0};
    v_parent_position = PwsGetAbsolutePosition(p_object.offsetParent);
    v_position.left += v_parent_position.left;
    v_position.top += v_parent_position.top;
  }

  return v_position;
}
// --------------------------------------------------------------------------------

// --------------------------------------------------------------------------------
// Function : PwsGetParentByType()
// Description :
// --------------------------------------------------------------------------------
function PwsGetParentByType(p_object, p_class_name)
{
  var v_parent=null;
  if (p_object == null)
    return null;
  if (p_object.className == p_class_name)
    return p_object;
  return PwsGetParentByType(p_object.parentNode, p_class_name);

}
// --------------------------------------------------------------------------------

// --------------------------------------------------------------------------------
// Function : PwsJavaEvent()
// Description :
// --------------------------------------------------------------------------------
function PwsJavaEvent_OLD(p_event, p_object, p_parameters)
{
  // ----- Calculate the URL
  var p_url = "?"+'pws_event='+p_event+"&pws_object="+p_object+"&"+p_parameters;

  //TBC alert("URL="+p_url);

  // ----- Set & calculate window size
  var v_width=340;
  var v_height=400;
  var v_left = (screen.width-v_width)/2;
  var v_top = (screen.height-v_height)/2;

  // ----- Set window properties
  var v_settings = 'width='+v_width+',height='+v_height+',top='+v_top+',left='+v_left+',scrollbars=yes,location=no,directories=no,status=no,menubar=no,toolbar=no,resizable=yes';
//    var v_settings = 'width='+v_width+',height='+v_height+',top='+v_top+',left='+v_left+',scrollbars=yes,location=no,directories=no,status=no,menubar=no,toolbar=no,resizable=no';


  // ----- Open window
  v_win = window.open(p_url, 'pws_action_window', v_settings);

  // ----- Give focus to window
  v_win.focus();
}
// --------------------------------------------------------------------------------

// --------------------------------------------------------------------------------
// Function : PwsJavaEventNew()
// Description :
// --------------------------------------------------------------------------------
function PwsJavaEventNew_OLD(p_event, p_object, p_target, p_parameters)
{
  var p_url;

  // ----- Compose the URL
  p_url = "?"+'pws_event='+p_event;

  // ----- Add (futur optional) calling_object
  //if (p_object != '')
  //{
    p_url = p_url+"&pws_object="+p_object;
  //}

  // ----- Add optional target
  if (p_target != '')
  {
    p_url = p_url+"&pws_target="+p_target;
  }

  // ----- Add parameters
  p_url = p_url+"&"+p_parameters;

  //TBC alert("URL="+p_url);

  // ----- Set & calculate window size
  var v_width=340;
  var v_height=400;
  var v_left = (screen.width-v_width)/2;
  var v_top = (screen.height-v_height)/2;

  // ----- Set window properties
  var v_settings = 'width='+v_width+',height='+v_height+',top='+v_top+',left='+v_left+',scrollbars=yes,location=no,directories=no,status=no,menubar=no,toolbar=no,resizable=yes';
//    var v_settings = 'width='+v_width+',height='+v_height+',top='+v_top+',left='+v_left+',scrollbars=yes,location=no,directories=no,status=no,menubar=no,toolbar=no,resizable=no';


  // ----- Open window
  v_win = window.open(p_url, 'pws_action_window', v_settings);

  // ----- Give focus to window
  v_win.focus();
}
// --------------------------------------------------------------------------------

// --------------------------------------------------------------------------------
// Function : PwsJavaEvent()
// Description :
// --------------------------------------------------------------------------------
function PwsJavaEvent(p_event, p_object, p_target /*, p_parameter_name, p_parameter_value */)
{
  // ----- Get the action window
  v_win=open('?pws_event=empty', 'pws_action_window');

  // ----- Create the form
  v_win.document.write('<HTML>');
  v_win.document.write('<body>');
  v_win.document.write('<form name="pws_action_form" method="post" action="?">');
  v_win.document.write('<input type="text" name="pws_event" value="'+p_event+'"></input>');
  v_win.document.write('<input type="text" name="pws_object" value="'+p_object+'"></input>');
  v_win.document.write('<input type="text" name="pws_target" value="'+p_target+'"></input>');
  for (var i=3; i<arguments.length-1; i+=2) {
    v_win.document.write('<input type="text" name="'+arguments[i]+'" value="'+arguments[i+1]+'"></input>');
  }
  v_win.document.write('<input type="submit" value="Click to continu"></input>');
  v_win.document.write('</form>');
  v_win.document.write('<body>');
  v_win.document.write('</HTML>');

  // ----- Submit the form
  v_win.document.pws_action_form.submit();
}
// --------------------------------------------------------------------------------

// --------------------------------------------------------------------------------
// Function : PwsJavaEventDisplay()
// Description :
// --------------------------------------------------------------------------------
function PwsJavaEventDisplay(p_object, p_window /*, p_parameter_name, p_parameter_value */)
{
  // ----- Look for default window
  if (p_window == '')
  {
    p_window = 'pws_main';
    var v_settings = '';
    //v_win = pws_main;

    // ----- Open window
    v_win = window.open('?', p_window, v_settings);
  }
  else
  {
    // ----- Settings of the window
    // TBC : should be from the parameters list
    var v_width=340;
    var v_height=400;
    var v_left = (screen.width-v_width)/2;
    var v_top = (screen.height-v_height)/2;
    var v_settings = 'width='+v_width+',height='+v_height+',top='+v_top+',left='+v_left+',scrollbars=yes,location=no,directories=no,status=no,menubar=no,toolbar=no,resizable=yes';

    // ----- Compose the URL
    //var v_url = "?"+'pws_event=pws_display&pws_object='+p_object+'&name='+p_window+"&"+p_parameters;

    // ----- Open window
    v_win = window.open('?', p_window, v_settings);
  }

  //alert('window='+p_window);


  // ----- Give focus to window
  v_win.focus();

  // ----- Create the form
  v_win.document.write('<HTML>');
  v_win.document.write('<body>');
  v_win.document.write('<p align=center>Refreshing, please wait ...</p>');
  v_win.document.write('<form name="pws_action_form" method="post" action="?">');
  v_win.document.write('<input type="hidden" name="pws_event" value="pws_display"></input>');
  v_win.document.write('<input type="hidden" name="pws_object" value="'+p_object+'"></input>');
  v_win.document.write('<input type="hidden" name="pws_target" value="'+p_window+'"></input>');
  v_win.document.write('<input type="hidden" name="name" value="'+p_window+'"></input>');
  for (var i=2; i<arguments.length-1; i+=2) {
    v_win.document.write('<input type="hidden" name="'+arguments[i]+'" value="'+arguments[i+1]+'"></input>');
  }
  //v_win.document.write('<input type="submit" value="Click to continu"></input>');
  v_win.document.write('</form>');
  v_win.document.write('<body>');
  v_win.document.write('</HTML>');

  // ----- Submit the form
  v_win.document.pws_action_form.submit();
}
// --------------------------------------------------------------------------------

// --------------------------------------------------------------------------------
// Function : PwsJavaEventDisplay()
// Description :
// --------------------------------------------------------------------------------
function PwsJavaEventDisplay_OLD(p_object, p_window, p_parameters)
{
  // ----- Look for default window
  if (p_window == '')
  {
    p_window = 'pws_main';
    var v_settings = '';
  }
  else
  {
    // ----- Settings of the window
    // TBC : should be from the parameters list
    var v_width=340;
    var v_height=400;
    var v_left = (screen.width-v_width)/2;
    var v_top = (screen.height-v_height)/2;
    var v_settings = 'width='+v_width+',height='+v_height+',top='+v_top+',left='+v_left+',scrollbars=yes,location=no,directories=no,status=no,menubar=no,toolbar=no,resizable=yes';
  }

  // ----- Compose the URL
  var v_url = "?"+'pws_event=pws_display&pws_object='+p_object+'&name='+p_window+"&"+p_parameters;

  // ----- Open window
  v_win = window.open(v_url, p_window, v_settings);

  // ----- Give focus to window
  v_win.focus();
}
// --------------------------------------------------------------------------------


// --------------------------------------------------------------------------------
// Class : PwsJavaBrowser()
// Description :
// --------------------------------------------------------------------------------
function PwsJavaBrowser()
{
  var ua, s, i;

  // ----- Navigator default type and version
  this.navigator = '';   // IE or NETSCAPE or MOZILLA
  this.version = '';

  // ----- Look for Internet Explorer
  var v_string = 'MSIE';
  var v_pos = navigator.userAgent.indexOf(v_string);
  if (v_pos >= 0)
  {
    this.navigator = 'IE';
    this.version = parseFloat( navigator.userAgent.substr(v_pos + v_string.length));
  }

  if (this.navigator == '')
  {
    // ----- Look for Netscape
    var v_string = 'Netscape';
    var v_pos = navigator.userAgent.indexOf(v_string);
    if (v_pos >= 0)
    {
      this.navigator = 'NETSCAPE';
      this.version = parseFloat( navigator.userAgent.substr(v_pos + v_string.length));
    }
  }

  if (this.navigator == '')
  {
    // ----- Look for generic Mozilla
    // TBC
    var v_string = 'Gecko/';
    var v_pos = navigator.userAgent.indexOf(v_string);
    if (v_pos >= 0)
    {
      this.navigator = 'MOZILLA';
      this.version = parseFloat( navigator.userAgent.substr(v_pos + v_string.length));
    }
  }

  if (this.navigator == '')
  {
    this.navigator = 'OTHER';
    this.version = '';
  }

  //alert("Agent="+navigator.userAgent);
  //alert("Navigator ="+this.navigator+', version ='+this.version);
}
// --------------------------------------------------------------------------------

// --------------------------------------------------------------------------------
// Global Varaible : pws_navigator
// Description :
// --------------------------------------------------------------------------------
var pws_navigator = new PwsJavaBrowser();
// --------------------------------------------------------------------------------


