<?
// --------------------------------------------------------------------------------
// PhpWindowSystem - PwsWindow Class
// --------------------------------------------------------------------------------
//
// Presentation :
//   PhpWindowSystem is a generic PHP window system management.
//   PhpWindowSystem is designed to take care of window displaying and
//   manage the associated events in order to offer a generic application
//   container.
//   More information can be obtained on
//   PhpConcept (http://www.phpconcept.net)
//   or by contacting the author Vincent Blavet (vincent@phpconcept.net)
//
// --------------------------------------------------------------------------------
// License :
//   PhpWindowSystem (PWS)
//   Copyright (C) 2002  Vincent Blavet (vincent@phpconcept.net)
//
//   This library is free software; you can redistribute it and/or
//   modify it under the terms of the GNU Lesser General Public
//   License as published by the Free Software Foundation; either
//   version 2.1 of the License, or (at your option) any later version.
//
//   This library is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//   Lesser General Public License for more details.
//
//   You should have received a copy of the GNU Lesser General Public
//   License along with this library; if not, write to the Free Software
//   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// --------------------------------------------------------------------------------
// CVS : $Id: pws-window.class.php,v 1.1 2002/08/26 22:07:43 vblavet Exp $
// --------------------------------------------------------------------------------

  // ----- Class objects
  require_once('pws/core/pws-object-graphical.class.php');

  // ----- Constant definition
  define ("PWS_WINDOW_SIZE_MAXIMIZE", 0);
  define ("PWS_WINDOW_SIZE_BEST", 1);

  define ("PWS_WINDOW_TYPE_MAIN", 0);
  define ("PWS_WINDOW_TYPE_POPUP", 1);
  define ("PWS_WINDOW_TYPE_CHILD", 2);
  define ("PWS_WINDOW_TYPE_ABOUT", 3);

  // ----- Class ID
  define ('PWS_WINDOW_ID', 10030000);

  // ----- Attributes definition
  define ("PWS_WINDOW_ATTRIBUTE_TYPE", PWS_WINDOW_ID+1);
  define ("PWS_WINDOW_ATTRIBUTE_NAME", PWS_WINDOW_ID+2);
  define ("PWS_WINDOW_ATTRIBUTE_TITLE", PWS_WINDOW_ID+3);
  define ("PWS_WINDOW_ATTRIBUTE_SIZE", PWS_WINDOW_ID+4);

  // --------------------------------------------------------------------------------
  // Class : PwsWindow
  // Description :
  // Attributes :
  // --------------------------------------------------------------------------------
  class PwsWindow extends PwsObjectGraphical
  {
    // ----- Attributes
    var $size;
    var $type;
    var $name;
    var $title;

    // ----- List of attached documents
    var $documents;

    // ----- Index of current selected document
    var $current_document;

    // ----- Maximum number of (open) documents
    var $document_max;

    // ----- Name of the document class to use
    var $document_classname;

    // --------------------------------------------------------------------------------
    // Method : PwsWindow()
    // Description :
    //   Constructor
    // --------------------------------------------------------------------------------
    function PwsWindow()
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsWindow::PwsWindow', "");

      // ----- Call the Parent constructor
      PwsObjectGraphical::PwsObjectGraphical();

      // ----- Initialize
      $this->size = 0;
      $this->type = PWS_WINDOW_TYPE_MAIN;
      $this->name = 'pws_main';
      $this->title = '';

      // ----- Document properties
      $this->document_max = 99;
      $this->document_classname = '';

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : pSetSingleAttribute()
    // Description :
    // --------------------------------------------------------------------------------
    function pSetSingleAttribute($p_name, $p_value)
    {
      $v_result=1;
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsWindow['.$this->id.']::pSetSingleAttribute', "name='$p_name', value='$p_value'");

      // ----- Look first for parent class attribute
      if (($v_result = PwsObjectGraphical::pSetSingleAttribute($p_name, $p_value)) == 0) {
        // ----- Set the attribute
        switch ($p_name)
        {
          case PWS_WINDOW_ATTRIBUTE_TYPE :
            $this->type = $p_value;
          break;
          case PWS_WINDOW_ATTRIBUTE_SIZE :
            $this->size = $p_value;
          break;
          case PWS_WINDOW_ATTRIBUTE_NAME :
            $this->name = $p_value;
          break;
          case PWS_WINDOW_ATTRIBUTE_TITLE :
            $this->title = $p_value;
          break;
          default :
            PwsTraceFctMessage(__FILE__, __LINE__, 2, "Unknown attribut '$p_name' for PwsWindow object");
            $v_result=0;
        }
      }

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, $v_result);
      return $v_result;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : add()
    // Description :
    // --------------------------------------------------------------------------------
    function add($p_child, $p_index=-1)
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsWindow['.$this->id.']::add', "child='".$p_child->id."', index=$p_index");

      // ----- Add a child
      $nb = sizeof($this->childs);
      PwsTraceFctMessage(__FILE__, __LINE__, 2, "Adding child at index $nb");
      $this->childs[$nb] = &$p_child;
      $p_child->pAttach(&$this, $p_index);

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : doEvent()
    // Description :
    // --------------------------------------------------------------------------------
    function doEvent(&$p_event)
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsWindow['.$this->id.']::doEvent', "");
      $v_result = 1;

      // ----- Get the default document
      if (($v_document = &$this->getDocument()) != 0)
      {
        // ----- Look if the method exist
        if (method_exists($v_document, 'event_'.$p_event->event))
        {
          PwsTraceFctMessage(__FILE__, __LINE__, 2, "Calling method '".'event_'.$p_event->event."'");
          $v_result = call_user_method('event_'.$p_event->event, $v_document, $p_event);
        }
        else
        {
          die ("Unknown event '".$p_event->event."' for the default document [".__FILE__.",".__LINE__."] of window ".$this->name);
        }
      }
      else
      {
        PwsTraceFctMessage(__FILE__, __LINE__, 2, "No default document exist");
      }

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, $v_result);
      return $v_result;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : readXmlToken()
    // Description :
    // --------------------------------------------------------------------------------
    function readXmlToken($p_parser, $p_name, $attrs)
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsWindow['.$this->id.']::readXmlToken', "name='$p_name'");

      // ----- Look for token name
      switch ($p_name)
      {
        case "TITLE" :
          PwsTraceFctMessage(__FILE__, __LINE__, 2, "Found token TITLE, create object");

          // ----- Create a new Title object
          $p_object = new PwsTitle();
          $this->add(&$p_object);

          // ----- Set the object & methods for the xml parser
          xml_set_object($p_parser, &$p_object);
        break;

        case "SEPARATOR" :
          PwsTraceFctMessage(__FILE__, __LINE__, 2, "Found token SEPARATOR, create object");

          // ----- Create a new Title object
          $p_object = new PwsSeparator();
          $this->add(&$p_object);

          // ----- Set the object & methods for the xml parser
          xml_set_object($p_parser, &$p_object);
        break;

        case "MENU" :
          PwsTraceFctMessage(__FILE__, __LINE__, 2, "Found token MENU, create object");

          // ----- Create a new Title object
          $p_object = new PwsMenu();
          $this->add(&$p_object);

          // ----- Set the object & methods for the xml parser
          xml_set_object($p_parser, &$p_object);
        break;

        case "FRAME" :
          PwsTraceFctMessage(__FILE__, __LINE__, 2, "Found token FRAME, create object");

          // ----- Create a new object
          $p_object = new PwsFRAME();
          $p_object->readXmlAttributs($attrs);
          $this->add(&$p_object);

          // ----- Set the object & methods for the xml parser
          xml_set_object($p_parser, &$p_object);
        break;

        case "FOOTER" :
          PwsTraceFctMessage(__FILE__, __LINE__, 2, "Found token FOOTER, create object");

          // ----- Create a new Title object
          $p_object = new PwsFooter();
          $this->add(&$p_object);

          // ----- Set the object & methods for the xml parser
          xml_set_object($p_parser, &$p_object);
        break;

        case "DOCUMENT" :
          if ((!isset($attrs['CLASS'])) || ($attrs['CLASS'] == ''))
          {
            die("Missing class name for document (".__FILE__.", ".__LINE__.")");
          }
          $this->document_classname = $attrs['CLASS'];
          if (isset($attrs['MAX_DOCUMENT']))
          {
            $this->document_max = $attrs['MAX_DOCUMENT'];
          }

          // ----- Create the first document
          // TBC : May be they will not be a default created document ....
          $this->pNewDocument();

        break;

        default :
          PwsTraceFctMessage(__FILE__, __LINE__, 2, "Unsupported token for this object");
          die("Unsupported token '$p_name' for WINDOW object (".__FILE__.", ".__LINE__.")");
      }

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : readXmlAttributs()
    // Description :
    // --------------------------------------------------------------------------------
    function readXmlAttributs($attrs)
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsWindow['.$this->id.']::readXmlAttributs', "");

      if (isset($attrs['TYPE']))
      {
        PwsTraceFctMessage(__FILE__, __LINE__, 2, "Window type is '".$attrs['TYPE']."'");
        switch ($attrs['TYPE']) {
          case 'main' :
            $this->setAttribute(PWS_WINDOW_ATTRIBUTE_TYPE, PWS_WINDOW_TYPE_MAIN);
          break;
          case 'popup' :
            $this->setAttribute(PWS_WINDOW_ATTRIBUTE_TYPE, PWS_WINDOW_TYPE_POPUP);
          break;
          case 'about' :
            $this->setAttribute(PWS_WINDOW_ATTRIBUTE_TYPE, PWS_WINDOW_TYPE_ABOUT);
          break;
          case 'help' :
            $this->setAttribute(PWS_WINDOW_ATTRIBUTE_TYPE, PWS_WINDOW_TYPE_HELP);
          break;
          case 'child' :
            $this->setAttribute(PWS_WINDOW_ATTRIBUTE_TYPE, PWS_WINDOW_TYPE_CHILD);
          break;
          default :
            die("Invalid value '".$attrs['TYPE']."' for PwsWindow attribute  (".__FILE__.", ".__LINE__.")");
        }
      }

      if (isset($attrs['NAME']))
      {
        PwsTraceFctMessage(__FILE__, __LINE__, 2, "Window name is '".$attrs['NAME']."'");
        $this->setAttribute(PWS_WINDOW_ATTRIBUTE_NAME, $attrs['NAME']);
      }

      if (isset($attrs['TITLE']))
      {
        PwsTraceFctMessage(__FILE__, __LINE__, 2, "Window title is '".$attrs['TITLE']."'");
        $this->setAttribute(PWS_WINDOW_ATTRIBUTE_TITLE, $attrs['TITLE']);
      }


      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : finishXmlToken()
    // Description :
    // --------------------------------------------------------------------------------
    function finishXmlToken($p_parser, $p_name)
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsWindow['.$this->id.']::finishXmlToken', "name='$p_name'");

      // ----- Look for token name
      switch ($p_name)
      {
        case "WINDOW" :
          PwsTraceFctMessage(__FILE__, __LINE__, 2, "End of PwsWindow object reading");

          // ----- Set the reference object back to the parent
          xml_set_object($p_parser, &$this->parent);

          // ----- Reset the working data
          $this->working_data = $p_name;

          // TBC : check for a futur 'nofooter' attribute
          // ----- Add a Footer
          $v_footer = & new PwsFooter();
          $this->add($v_footer);

        break;
        case "DOCUMENT" :
          PwsTraceFctMessage(__FILE__, __LINE__, 2, "End of attribute data, reset working data");
          $this->working_data = '';
        break;
        default :
          PwsTraceFctMessage(__FILE__, __LINE__, 2, "Unsupported token for this object");
      }

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : readXmlTokenContent()
    // Description :
    // --------------------------------------------------------------------------------
    function readXmlTokenContent($p_parser, $p_data)
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsWindow['.$this->id.']::readXmlTokenContent', "data='$p_data'");

      // ----- Look for object type
      switch ($this->working_data)
      {
      /*
        case "NAME" :
        case "VERSION" :
        case "ICON" :
          if (trim($p_data) != "")
          {
            PwsTraceFctMessage(__FILE__, __LINE__, 2, "Setting attribute ".$this->working_data." to '".$p_data."'");
            $this->setAttribute('PWS_APPLICATION_ATTRIBUTE_'.$this->working_data, trim($p_data));
          }
        break;
        */
        default :
          ;
      }

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : getDocument()
    // Description :
    // --------------------------------------------------------------------------------
    function &getDocument($p_index=-1)
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsWindow::getDocument', "index='$p_index'");

      // ----- Look for classname
      if ($this->document_classname == '')
      {
        // ----- The parent is always a PwsApplication
        $v_result = & $this->parent->getDocument($p_index);

        // ----- Return
        PwsTraceFctEnd(__FILE__, __LINE__, $v_result);
        return $v_result;
      }

      // ----- Get the document
      if ($p_index <0 )
      {
        $v_document = &$this->documents[$this->current_document];
      }
      else
      {
        $v_document = &$this->documents[$p_index];
      }

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, $v_result);
      return $v_document;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : pAttach()
    // Description :
    // --------------------------------------------------------------------------------
    function pAttach($p_parent, $p_index=-1)
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsWindow['.$this->id.']::pAttach', "parent='".$p_parent->id."', index=$p_index");

      // ----- Add a child
      $this->parent = &$p_parent;

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : pNewDocument()
    // Description :
    // --------------------------------------------------------------------------------
    function pNewDocument()
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsWindow::pNewDocument', "");

      // ----- Look for classname
      if ($this->document_classname == '')
      {
        PwsTraceFctMessage(__FILE__, __LINE__, 2, "No document associated with this window");

        // ----- Return
        PwsTraceFctEnd(__FILE__, __LINE__, 0);
        return 0;
      }

      // ----- Get index
      $v_index = sizeof($this->documents);
      PwsTraceFctMessage(__FILE__, __LINE__, 2, "".$v_index." documents already in the list");

      // ----- Look for max reached
      if ($v_index > $this->document_max)
      {
        // TBC
        PwsTraceFctMessage(__FILE__, __LINE__, 2, "Max number of document reached");
      }
      else
      {
        // ----- Create the document
        PwsTraceFctMessage(__FILE__, __LINE__, 2, "Creating a document of class '".$this->document_classname."'");
        eval ("\$this->documents[".$v_index."] = & new ".$this->document_classname."();");
        $this->current_document = $v_index;
      }

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return 1;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : event_pws_header_display()
    // Description :
    //   TBC : Futur use .... to be able to add HTML lines in <header> token
    // --------------------------------------------------------------------------------
    function event_pws_header_display(&$p_event)
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsWindow['.$this->id.']::event_pws_header_display', "");

      // ----- Display the childs graphical objects
      if (($nb=sizeof($this->childs))!=0)
      {
        for ($i=0; $i<$nb; $i++)
        {
          $this->childs[$i]->event_pws_header_display($p_event);
        }
      }

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : event_pws_style_display()
    // Description :
    //   TBC : Futur use .... to be able to add style in <header> token
    // --------------------------------------------------------------------------------
    function event_pws_style_display(&$p_event)
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsWindow['.$this->id.']::event_pws_style_display', "");

      // ----- Display the childs graphical objects
      if (($nb=sizeof($this->childs))!=0)
      {
        for ($i=0; $i<$nb; $i++)
        {
          $this->childs[$i]->event_pws_style_display($p_event);
        }
      }

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : event_pws_script_display()
    // Description :
    //   TBC : Futur use .... to be able to add <script> at the beginning of <body>
    //         token
    // --------------------------------------------------------------------------------
    function event_pws_script_display(&$p_event)
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsWindow['.$this->id.']::event_pws_script_display', "");

      // ----- Set the name of the window (if any)
      if (1)//$this->name != "")
      {
?>
<script language="JavaScript1.2">
window.name="<? echo $this->name; ?>";
</script>
<?php
      }

      // ----- Include the generic scripts
?>
<script language="JavaScript1.2">
<?php
  readfile('pws/core/pws-utilities.js.php', 1);
  readfile('pws/core/pws-menu.js.php', 1);
?>
</script>

<?php

      // ----- Display the childs graphical objects
      if (($nb=sizeof($this->childs))!=0)
      {
        for ($i=0; $i<$nb; $i++)
        {
          $this->childs[$i]->event_pws_script_display($p_event);
        }
      }

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

     // --------------------------------------------------------------------------------
    // Method : event_pws_pre_display()
    // Description :
    // --------------------------------------------------------------------------------
    function event_pws_pre_display(&$p_event)
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsWindow::event_pws_pre_display', "");

      /*
?>
<body bgcolor="#FFFFFF" text="#000000" LEFTMARGIN="0" TOPMARGIN="0">
<script language="JavaScript1.2">
< ?php
  readfile('pws/core/pws-utilities.js.php', 1);
  readfile('pws/core/pws-menu.js.php', 1);
? >
</script>

< ?php
//<script language="JavaScript1.2" src="pws/core/pws-utilities.js.php"></script>
//<script language="JavaScript1.2" src="pws/core/pws-menu.js.php"></script>

      // ----- Display the HTML Header and properties
      if ($this->name != "")
      {
? >
<script language="JavaScript1.2">
window.name="< ? echo $this->name; ? >";
</script>
< ?php
      }

      */
      // ----- Display the childs graphical objects
      if (($nb=sizeof($this->childs))!=0)
      {
        for ($i=0; $i<$nb; $i++)
        {
          $this->childs[$i]->event_pws_pre_display($p_event);
        }
      }

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : event_pws_display()
    // Description :
    // --------------------------------------------------------------------------------
    function event_pws_display(&$p_event)
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsWindow::event_pws_display', "");

      PwsTraceFctMessage(__FILE__, __LINE__, 5, "WINDOW has ".sizeof($this->childs)." childs");

      // ----- Display the header section
?>
<head>
<?php

      // ----- Display the header informations
      $this->event_pws_header_display($p_event);

      // ----- Display the style informations
      $this->event_pws_style_display($p_event);

      // ----- End of the header section
?>
</head>
<?php

      // ----- Display the body section
?>
<body bgcolor="#FFFFFF" text="#000000" LEFTMARGIN="0" TOPMARGIN="0">
<?php

      // ----- Display the script informations
      $this->event_pws_script_display($p_event);

      // ----- Display the hidden elements
      $this->event_pws_pre_display($p_event);

      // ----- Display Items table
?>
<div class="PwsWindowBorder1">
<div class="PwsWindowBorder2">
<div class="PwsWindowBorder3">
<?php
/*
  <table width="100%" border="0" cellspacing="0" cellpadding="0" name="ItemTable">
*/
?>
<?php
      // ----- Display the childs graphical objects
      if (($nb=sizeof($this->childs))!=0)
      {
        for ($i=0; $i<$nb; $i++)
        {
?>
<?php
/*
  <tr bgcolor="#CCCCCC">
    <td bgcolor="#CCCCCC" valign="top">
*/
?>
    <?php $this->childs[$i]->event_pws_display($p_event); ?>
<?php
/*
    </td>
  </tr>
*/
?>
<?php
        }
      }
      else
      {
        PwsTraceFctMessage(__FILE__, __LINE__, 2, "No objects defined in the application");
      }

      // ----- Display end of childs table
?>
<?php
/*
  </table>
*/
?>
</div>
</div>
</div>
<?php

      // ----- Display the application WINDOW footer
      //$this->pDisplayFooter();

      // ----- Display the Post dispaly function
      $this->event_pws_post_display($p_event);

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : event_pws_post_display()
    // Description :
    // --------------------------------------------------------------------------------
    function event_pws_post_display(&$p_event)
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsApplication::event_pws_post_display', "");

      // ----- Display the childs graphical objects
      if (($nb=sizeof($this->childs))!=0)
      {
        for ($i=0; $i<$nb; $i++)
        {
          $this->childs[$i]->event_pws_post_display($p_event);
        }
      }

      // ----- Display end of page and hidden window for actions
?>
<br>
<?php
        // TBC : note that for debugging put the iframe in comment
        // ----- Do not hide the window when trace is on
        if ($this->name == 'pws_main') {
?>
<iframe name="pws_action_window" width=0 height=0 marginwidth=0 marginheight=0 hspace=0 vspace=0 frameborder=1 scrolling=no></iframe>
<?php
        }

?>
</body>
<?php

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

  }
  // End of class
  // --------------------------------------------------------------------------------

?>
