<?
// --------------------------------------------------------------------------------
// PhpWindowSystem - PwsExplorer Module Class
// --------------------------------------------------------------------------------
//
// Presentation :
//   PhpWindowSystem is a generic PHP window system management.
//   PhpWindowSystem is designed to take care of window displaying and
//   manage the associated events in order to offer a generic application
//   container.
//   More information can be obtained on
//   PhpConcept (http://www.phpconcept.net)
//   or by contacting the author Vincent Blavet (vincent@phpconcept.net)
//
// --------------------------------------------------------------------------------
// License :
//   PhpWindowSystem (PWS)
//   Copyright (C) 2002  Vincent Blavet (vincent@phpconcept.net)
//
//   This library is free software; you can redistribute it and/or
//   modify it under the terms of the GNU Lesser General Public
//   License as published by the Free Software Foundation; either
//   version 2.1 of the License, or (at your option) any later version.
//
//   This library is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//   Lesser General Public License for more details.
//
//   You should have received a copy of the GNU Lesser General Public
//   License along with this library; if not, write to the Free Software
//   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// --------------------------------------------------------------------------------
// CVS : $Id: pws-module-explorer.class.php,v 1.1 2002/08/26 22:09:42 vblavet Exp $
// --------------------------------------------------------------------------------

  // ----- Inludes
  require_once('pws/core/pws-object-graphical.class.php');

  // ----- Constant definition
  define ("PWS_EXPLORER_MODE_OPEN", 0);
  define ("PWS_EXPLORER_MODE_SAVE_AS", 1);
  define ("PWS_EXPLORER_MODE_SELECT", 2);

  define ("PWS_EXPLORER_SELECT_FILE", 0);
  define ("PWS_EXPLORER_SELECT_DIRECTORY", 1);

  define ("PWS_EXPLORER_IMAGES_DIR", 'pws/modules/pws-module-explorer/images/');

  // ----- Class ID
  define ('PWS_EXPLORER_ID', 20010000);

  // ----- Attributes definition
  define ("PWS_EXPLORER_ATTRIBUTE_MODE", PWS_EXPLORER_ID+1);

  // --------------------------------------------------------------------------------
  // Class : PwsExplorer
  // Description :
  //   This object accept the following events :
  //     'start' : initialize and display the explorer window. The event takes the
  //               following parameters :
  //               'mode' : indicates if the explorer is used for an 'open' (0),
  //                        'select' (2) or 'save_as' (1) action.
  //                'start_dir' :
  //                'calling_dir' :
  //                'selection_type' : FUTUR / Selection of file or directory.
  //                'return_event' : The event name that must be called back at
  //                                 the end of the selection.
  //                'return_parameter' : The name of the event parameter that will
  //                                     contain the filename (or dir) selected.
  //                'return_target' : The window target (if != pws_main) that
  //                                  should receive the event.
  //     'display' : display a current directory. Should not be directly used by
  //                 the user (internal event)
  //     'select' : the selection is done and will be send to the return target.
  //                Should not be directly used by the user (internal event)
  // Attributes :
  // --------------------------------------------------------------------------------
  class PwsModuleExplorer extends PwsObjectGraphical
  {
    // ----- Attributes
    var $mode; // PWS_EXPLORER_MODE_OPEN or PWS_EXPLORER_MODE_SAVE_AS
    var $calling_dir;
    var $start_dir;
    var $current_dir;
    var $selection_type;
    var $return_event;
    var $return_parameter;
    var $return_target;

    // --------------------------------------------------------------------------------
    // Method : PwsExplorer()
    // Description :
    //   Constructor
    // --------------------------------------------------------------------------------
    function PwsModuleExplorer()
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsModuleExplorer::PwsModuleExplorer', "");

      PwsObjectGraphical::PwsObjectGraphical();

      $this->mode = PWS_EXPLORER_MODE_SELECT;
      $this->selection_type = PWS_EXPLORER_SELECT_FILE;
      $this->return_event = '';
      $this->return_parameter = '';
      $this->return_target = '';

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : event_start()
    // Description :
    // --------------------------------------------------------------------------------
    function event_start(&$p_event)
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsModuleExplorer::event_start', "");

      // ----- Set the mode
      // TBC : depend on the event parameter : look for uppercase or lowercase ....
      if (isset($p_event->parameters['mode'])) {
        PwsTraceFctMessage(__FILE__, __LINE__, 2, "Receiving mode='".$p_event->parameters['mode']."'");

        // ----- Look for parameter passed as a string
        switch ($p_event->parameters['mode']) {
        case 'open' :
          $this->mode = PWS_EXPLORER_MODE_OPEN;
        break;
        case 'save_as' :
          $this->mode = PWS_EXPLORER_MODE_SAVE_AS;
        break;
        case 'select' :
          $this->mode = PWS_EXPLORER_MODE_SELECT;
        break;
        default:
          // ----- Default is parameter passed as a value
          $this->mode = $p_event->parameters['mode'];
        }
        PwsTraceFctMessage(__FILE__, __LINE__, 2, "Mode set to ".$this->mode);
      }
      else {
        PwsTraceFctMessage(__FILE__, __LINE__, 2, "Mode not specified, set to Select");
        $this->mode = PWS_EXPLORER_MODE_SELECT;
      }

      // ----- Look for return informations
      if (isset($p_event->parameters['return_event'])) {
        $this->return_event = $p_event->parameters['return_event'];
      }
      else {
        $this->return_event = $p_event->parameters['return_event'];
      }
      PwsTraceFctMessage(__FILE__, __LINE__, 2, "return_event set to '".$p_event->parameters['return_event']."'");
      if (isset($p_event->parameters['return_target'])) {
        $this->return_target = $p_event->parameters['return_target'];
      }
      else {
        $this->return_event = $p_event->parameters['return_event'];
      }
      PwsTraceFctMessage(__FILE__, __LINE__, 2, "return_target set to '".$p_event->parameters['return_target']."'");
      if (isset($p_event->parameters['return_parameter'])) {
        $this->return_parameter = $p_event->parameters['return_parameter'];
      }
      else {
        $this->return_event = $p_event->parameters['return_event'];
      }
      PwsTraceFctMessage(__FILE__, __LINE__, 2, "return_parameter set to '".$p_event->parameters['return_parameter']."'");

      // ----- Look for the first call to the window
      if (isset($p_event->parameters['calling_dir']) || isset($p_event->parameters['start_dir'])) {
        $this->calling_dir = $p_event->parameters['calling_dir'];
        $this->start_dir = $p_event->parameters['start_dir'];

        // ----- Calculate the absolute start path ($PATH_INFO as 'root' reference)
        //       The absolute start path is composed by the absolute path of the
        //       calling script + the relative start path from that calling script.
        //       The result is reduced.
        $v_abs_start_path = PcsExplorerPathReduction($this->calling_dir."/".$this->start_dir);

        PwsTraceFctMessage(__FILE__, __LINE__, 2, "Absolute calling path='$this->calling_dir'");
        PwsTraceFctMessage(__FILE__, __LINE__, 2, "Relative start path='$this->start_dir'");
        PwsTraceFctMessage(__FILE__, __LINE__, 2, "Absolute start path='$v_abs_start_path'");

        // ----- Calculate the relative start path for PcsExplorer
        //       The relative path of the start path is needed to navigate
        //       from the PcsExplorer script.
        $v_script_dir = dirname($PATH_INFO);
        $this->current_dir = PcsExplorerPathRelative($v_script_dir, $v_abs_start_path);
      }

      PwsTraceFctMessage(__FILE__, __LINE__, 2, "Home directory='$this->current_dir'");

      // ----- Send an event for refreshing display
      //$v_parameters['name']='pws_explorer';
      //$v_parameters['current_dir']=$this->current_dir;
      PwsEventSend('pws_display', 0,
                   'name', 'pws_explorer',
                   'current_dir', $this->current_dir);

      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 0);
      return 0;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : event_pws_pre_display()
    // Description :
    // --------------------------------------------------------------------------------
    function event_pws_pre_display(&$p_event)
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsModuleExplorer::event_pws_pre_display', "");

?>
<script language="Javascript1.2">
function PcjsExplorerSelect(p_value)
{
  pceformulaire.a_dir.value = p_value;
}

function PcjsExplorerOpendir(p_value)
{
  pceformulaire.a_dir.value = p_value;
  //v_parameters = 'name=pws_explorer&current_dir='+p_value;
  PwsJavaEventDisplay(0, 'pws_explorer', 'name', 'pws_explorer',
                                         'current_dir', p_value);
}

function PcjsExplorerSelectDir()
{
  if (pceformulaire.a_dir.value=='') {
    alert('Invalid empty selection');
  }
  else {
    //v_parameters = 'selection='+pceformulaire.a_dir.value;
    PwsJavaEvent('select', 0, 'pws_explorer', 'selection', pceformulaire.a_dir.value);
    window.close();
  }
}

function PcjsExplorerClose()
{
  window.close();
}
</script>
<?php
      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : event_pws_display()
    // Description :
    // --------------------------------------------------------------------------------
    function event_pws_display(&$p_event)
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsModuleExplorer::event_pws_display', "");


      // ----- Adapt PcsExplorer code to Pws system
      if (isset($p_event->parameters['current_dir'])) {
        PwsTraceFctMessage(__FILE__, __LINE__, 2, "Parameter current_dir is '".$this->current_dir."'");
        $this->current_dir = $p_event->parameters['current_dir'];
      }
      $p_dir = $this->current_dir;
      PwsTraceFctMessage(__FILE__, __LINE__, 2, "Home dir is '".$p_dir."'");
      // Indicates that we want to see files and dir
      $a_type = 'file';

?>

<form name="pceformulaire" method="post" action="?">

<div id="Layer1" style="width:300px; height:200px; overflow: auto; margin: 10px 10px; background-color: #FFFFFF; layer-background-color: #FFFFFF; border: 1px none #000000">

<?

    // ----- Look for empty directory
    if ($p_dir == "")
    {
      $p_dir = ".";

      // ----- Flag to indicate that the directory was not set
      $v_dir_new = 1;
    }

    // ----- File / directory table
    echo "<table border=0 cellspacing=0 cellpadding=0 width=100%>";
    echo "<tr bgcolor=#0000CC>";
    echo "<td width=10></td>";
    //echo "<td></td>";
    echo "<td colspan=2><div><font face='Verdana, Arial, Helvetica, sans-serif' size=3 color=white>Folder</font></div></td>";
    echo "<td><div><font face='Verdana, Arial, Helvetica, sans-serif' size=3 color=white>Size</font></div></td>";
    echo "<td width=10></td></tr>";

    // ----- Scan the current directory
    $v_hdir = opendir($p_dir);
    $v_file = readdir($v_hdir); // '.' directory

    // ----- Look for each entry in the directory
    for ($i=0; $v_file = readdir($v_hdir); $i++)
    {
      // ----- Look for parent directory
      if ($v_file == "..")
      {
        PwsTraceFctMessage(__FILE__, __LINE__, 4, "Parent directory");

        // ----- Look for first parent
        if (($p_dir == "..") || ((substr($p_dir, 0,2) == "..") && (substr($p_dir, -2) == "..")))
        {
          PwsTraceFctMessage(__FILE__, __LINE__, 4, "First parent found");
          $v_file_full = "../".$p_dir;
        }
        // ----- Look for the current dir
        else if ($p_dir == ".")
        {
          PwsTraceFctMessage(__FILE__, __LINE__, 4, "Current dir found");
          $v_file_full = "..";
        }
        // ----- Look for other path
        else
        {
          PwsTraceFctMessage(__FILE__, __LINE__, 4, "Remove last part of the path '$p_dir'");

          // ----- Remove the last part of the path
          $temp = strrchr($p_dir, "/");
          $v_file_full = substr($p_dir, 0, strlen($p_dir)-strlen($temp));
          unset($temp);
        }

        PwsTraceFctMessage(__FILE__, __LINE__, 4, "Calculated path for parent is : '$v_file_full'");

        // ----- Look if the file is a file parent directory (indirect check of open_basedir restriction)
        if ($v_test_hdir = @opendir($v_file_full))
        {
          PwsTraceFctMessage(__FILE__, __LINE__, 4, "'$v_file_full' can be opened");

          // ----- Close the temporary handle
          closedir($v_test_hdir);

          // ----- Display the name in the table without checkbox
          echo "<tr><td width=10></td>";
          //echo "<td></td>";
          echo "<td colspan=2><font face='Verdana, Arial, Helvetica, sans-serif' size=2><A ";
          if ($a_type=="dir")
            //echo "onClick='PcjsExplorerSelect(\"$v_file_full\");' ";
            echo "onClick='PcjsExplorerSelect(\"$v_file\");' ";
          echo "onDblClick='PcjsExplorerOpendir(\"$v_file_full\");'><img src='".PwsUtilModuleImageSrc('folder02-16.gif', 'pws-module-explorer')."' border='0' hspace='0' vspace='0'> [Parent folder]</A></td><td></td>";
          echo "<td></td></font></tr>";
        }
        else
        {
          PwsTraceFctMessage(__FILE__, __LINE__, 4, "'$v_file_full' can not be opened");

          // ----- Display the name in the table without checkbox
          echo "<tr bgcolor=$g_text_bg><td width=10></td>";
          //echo "<td></td>";
          echo "<td colspan=2><font face='Verdana, Arial, Helvetica, sans-serif' size=2><img src='".PwsUtilModuleImageSrc('folder02-16.gif', 'pws-module-explorer')."' border='0' hspace='0' vspace='0'> [No parent folder]</td><td></td><td></td>";
          echo "</font></tr>";
        }
      }

      // ----- Look for normal file or directory
      else
      {
        // ----- Compose the full name
        $v_file_full = $p_dir."/".$v_file;

        PwsTraceFctMessage(__FILE__, __LINE__, 4, "Calculated full path is : '$v_file_full'");

        // ----- Look for directory
        if (is_dir($v_file_full))
        {
          PwsTraceFctMessage(__FILE__, __LINE__, 4, "'$v_file_full' is a directory");

          // ----- Display
          echo "<tr><td width=10></td>";

          if (is_readable($v_file_full))
          {
            PwsTraceFctMessage(__FILE__, __LINE__, 4, "is readable");

            echo "<td width=10></td>";
            echo "<td><font face='Verdana, Arial, Helvetica, sans-serif' size=2>";
            echo "<A ";
            if ($a_type == "dir")
              //echo "onClick='PcjsExplorerSelect(\"$v_file_full\");' ";
              echo "onClick='PcjsExplorerSelect(\"$v_file\");' ";
            echo "onDblClick='PcjsExplorerOpendir(\"$v_file_full\");'";
            echo "><img src='".PwsUtilModuleImageSrc('folder01-16.gif', 'pws-module-explorer')."' border='0' hspace='0' vspace='0'> $v_file</A></font></td>";
            echo "<td>-</td><td></td>";
          }
          else
          {
            PwsTraceFctMessage(__FILE__, __LINE__, 4, "is not readable");

            echo "<td width=10></td>";
            echo "<td><font face='Verdana, Arial, Helvetica, sans-serif' size=2><img src='".PwsUtilModuleImageSrc('folder01-16.gif', 'pws-module-explorer')."' border='0' hspace='0' vspace='0'>$v_file</font></td>";
            echo "<td>-</td><td></td>";
          }
          echo "</tr>";
        }

        // ----- Look for files
        else if ($a_type == "file")
        {
          PwsTraceFctMessage(__FILE__, __LINE__, 4, "'$v_file_full' is a file");

          $v_display = 1;

          if ($a_filter_extension != "")
          {
            PwsTraceFctMessage(__FILE__, __LINE__, 3, "look for extensions");

            // ----- Get the file extension
            $v_extension = substr(strrchr($v_file_full, '.'), 1);

            // ----- Look if in the list of filtered extensions
            $v_item = explode(' ', $a_filter_extension);
            for ($i=0, $v_display=0; $i<sizeof($v_item) && !$v_display; $i++)
            {
              if ($v_item[$i] == $v_extension)
              {
                $v_display=1;
              }
            }
          }

          // ----- Display only if respect filters
          if ($v_display)
          {
          // ----- Display
          echo "<tr><td width=10></td>";

          // ----- Select icon depending on file extension
          $v_icon = PcsExplorerImageFromExtension($v_file_full);

          if (is_readable($v_file_full))
          {
            PwsTraceFctMessage(__FILE__, __LINE__, 4, "is readable");
            echo "<td width=10></td>";
          }
          else
          {
            PwsTraceFctMessage(__FILE__, __LINE__, 4, "is not readable");
            echo "<td width=10></td>";
          }
          echo "<td><font face='Verdana, Arial, Helvetica, sans-serif' size=2>";
          echo "<A onClick='PcjsExplorerSelect(\"$v_file\");' onDblClick='PcjsExplorerSelectDir();'><img src='".PwsUtilModuleImageSrc($v_icon, 'pws-module-explorer')."' border='0' hspace='0' vspace='0'> $v_file</a></font></td>\n";
          echo "<td>".filesize($v_file_full)."</td><td></td>";
          echo "</tr>";
          }
        }
      }

?>

<?
    }

    echo "</table>";

    // ----- Close the directory handle
    closedir($v_hdir);


    PwsTraceFctMessage(__FILE__, __LINE__, 4, "mode is '".$this->mode."'");
    switch ($this->mode) {
    case PWS_EXPLORER_MODE_OPEN :
      $v_button_name = 'Open';
    break;
    case PWS_EXPLORER_MODE_SAVE_AS :
      $v_button_name = 'Save as';
    break;
    default :
      $v_button_name = 'Select';
    }

?>
</div>

<div >
<p align=center>
<font face="Verdana, Arial, Helvetica, sans-serif" size=2>
<? echo ($a_type=="file"?"File":"Directory")." :"; ?>
&nbsp;
<INPUT TYPE="TEXT"  name="a_dir" value="<? /*echo $p_dir;*/ ?>" align="middle" size="30" maxlength="255"   title="Selected directory">
</font>
<br>
<br>
<INPUT TYPE="SUBMIT" value="<? echo $v_button_name; ?>" onclick="PcjsExplorerSelectDir(); return false;">
&nbsp;
<INPUT TYPE="SUBMIT" value="Cancel"  onclick="PcjsExplorerClose(); return false;">
</p>

<?php
/*
  <input type=hidden name=a_action value=explorer>
  <input type=hidden name=a_target value="<? echo $a_target; ?>">
  <input type=hidden name=a_type value="<? echo $a_type; ?>">
  <input type=hidden name=a_home_dir value="<? echo $this->current_dir; ?>">
  <input type=hidden name=a_calling_dir value="<? echo $this->calling_dir; ?>">
  <input type=hidden name=a_target_type value="<? echo $a_target_type; ?>">
  <input type=hidden name=a_target_argument_name value="<? echo $a_target_argument_name; ?>">
  <input type=hidden name=a_filter_extension value="<? echo $a_filter_extension; ?>">
*/
?>

</div>
</form>
<?php
      // ----- Return
      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return;
    }
    // --------------------------------------------------------------------------------

    // --------------------------------------------------------------------------------
    // Method : event_select()
    // Description :
    // --------------------------------------------------------------------------------
    function event_select(&$p_event)
    {
      PwsTraceFctStart(__FILE__, __LINE__, 'PwsModuleExplorer::event_select', "");

/*
<script language="Javascript1.2">
alert("event_select : <? echo $p_event->parameters['selection']; ?>");
</script>
*/
?>
<?php
      // ----- Look for a valid selection
      if ($p_event->parameters['selection'] != '') {
        $v_filename = '';
        if ($this->current_dir != '') {
          $v_filename .= $this->current_dir.'/';
        }
        $v_filename .= $p_event->parameters['selection'];

        // ----- Look for defaults
        if ($this->return_event == '') {
          PwsTraceFctMessage(__FILE__, __LINE__, 4, "No return event defined by user");
          switch ($this->mode) {
          case PWS_EXPLORER_MODE_OPEN :
            $this->return_event = 'pws_open';
          break;
          case PWS_EXPLORER_MODE_SAVE_AS :
            $this->return_event = 'pws_save_as';
          break;
          case PWS_EXPLORER_MODE_SELECT :
            $this->return_event = 'pws_open';
          break;
          default :
            $this->return_event = 'pws_open';
          }
          PwsTraceFctMessage(__FILE__, __LINE__, 4, "Return event is defaulted to '".$this->return_event."'");
        }
        else {
          PwsTraceFctMessage(__FILE__, __LINE__, 4, "Return event is defined by user to '".$this->return_event."'");
        }
        if ($this->return_target == '') {
          $this->return_target = 'pws_main';
          PwsTraceFctMessage(__FILE__, __LINE__, 4, "Return target is defaulted to '".$this->return_target."'");
        }
        else {
          PwsTraceFctMessage(__FILE__, __LINE__, 4, "Return target is defined by user to '".$this->return_target."'");
        }
        if ($this->return_parameter == '') {
          $this->return_parameter = 'filename';
          PwsTraceFctMessage(__FILE__, __LINE__, 4, "Return parameter is defaulted to '".$this->return_parameter."'");
        }
        else {
          PwsTraceFctMessage(__FILE__, __LINE__, 4, "Return parameter is defined by user to '".$this->return_parameter."'");
        }

        // ----- Send an event for refreshing display
        PwsEventSendWithTarget($this->return_event, 0, $this->return_target,
                               $this->return_parameter, $v_filename);
      }
      else {
        // TBC : Should send a warning or an error message
        PwsEventSendWithTarget('pws_display', 0, 'pws_explorer',
                               'name', 'pws_explorer');
      }

      PwsTraceFctEnd(__FILE__, __LINE__, 1);
      return 1;
    }
    // --------------------------------------------------------------------------------

  }
  // End of class
  // --------------------------------------------------------------------------------


// TBC : Following functions will need to be completely re-worked

  // --------------------------------------------------------------------------------
  // Function : PcsExplorerPathReduction()
  // Description :
  // Parameters :
  // Return Values :
  // --------------------------------------------------------------------------------
  function PcsExplorerPathReduction($p_dir)
  {
    PwsTraceFctStart(__FILE__, __LINE__, "PcsExplorerPathReduction", "dir='$p_dir'");
    $v_result = "";

    // ----- Look for not empty path
    if ($p_dir != "")
    {
      // ----- Explode path by directory names
      $v_list = explode("/", $p_dir);
      $v_path = array();

      // ----- Study directories from last to first
      for ($i=0, $j=0; $i<sizeof($v_list); $i++)
      {
        PwsTraceFctMessage(__FILE__, __LINE__, 4, "Looking for path i=$i '".$v_list[$i]."', j=$j");

        // ----- Look for current path
        if (($v_list[$i] == ".") && ($i != 0))
        {
          // ----- Ignore this directory only if not the first
        }
        else if ($v_list[$i] == "..")
        {
          // ----- Ignore the last entry in the path (if at least one entry)
          $j = ($j>0?$j-1:0);
          PwsTraceFctMessage(__FILE__, __LINE__, 4, ".. found j=$j");
        }
        else if (($v_list[$i] == "") && ($i!=(sizeof($v_list)-1)) && ($i!=0))
        {
          // ----- Ignore only the double '//' in path,
          // but not the first and last '/'
        }
        else
        {
          PwsTraceFctMessage(__FILE__, __LINE__, 4, "Set j=$j to '".$v_list[$i]."'");
          $v_path[$j++] = $v_list[$i];
        }
      }
    }

    // ----- Compose the full path
    if ($j>0)
    {
      $v_result = $v_path[0];
      for ($i=1; $i<$j; $i++)
        $v_result = $v_result."/".$v_path[$i];
    }
    else
      $v_result = "";

    // ----- Return
    PwsTraceFctEnd(__FILE__, __LINE__, $v_result);
    return $v_result;
  }
  // --------------------------------------------------------------------------------

  // --------------------------------------------------------------------------------
  // Function : PcsExplorerPathRelative()
  // Description :
  // Parameters :
  // Return Values :
  // --------------------------------------------------------------------------------
  function PcsExplorerPathRelative($p_from_dir, $p_path)
  {
    PwsTraceFctStart(__FILE__, __LINE__, "PcsExplorerPathReduction", "from_dir='$p_from_dir', path='$p_path'");
    $v_result = "";

    // ----- Explode the paths
    $v_from = explode("/", $p_from_dir);
    $v_path = explode("/", $p_path);

    // ----- Look for common part of the path
    $i=0;
    while (($i < sizeof($v_from)) && ($i < sizeof($v_path)) && ($v_from[$i] == $v_path[$i]))
    {
      PwsTraceFctMessage(__FILE__, __LINE__, 4, "Same Item $i '".$v_from[$i]."'");
      $i++;
    }

    // ----- Look for path to remove
    for ($j=$i; $j< sizeof($v_from); $j++)
    {
      PwsTraceFctMessage(__FILE__, __LINE__, 4, "Remove Item $j '".$v_from[$j]."'");
      if (($v_from[$j] != "") && ($v_from[$j] != "."))
        $v_result = $v_result."../";
    }

    // ----- Look for path to add
    for ($j=$i; $j<sizeof($v_path); $j++)
    {
      PwsTraceFctMessage(__FILE__, __LINE__, 4, "Add Item $j '".$v_path[$j]."'");
      if (($v_path[$j] != "") && ($v_path[$j] != "."))
        $v_result = $v_result.$v_path[$j]."/";
    }

    // ----- Return
    PwsTraceFctEnd(__FILE__, __LINE__, $v_result);
    return $v_result;
  }
  // --------------------------------------------------------------------------------

  // --------------------------------------------------------------------------------
  // Function : PcsExplorerImageFromExtension()
  // Description :
  //
  // --------------------------------------------------------------------------------
  function PcsExplorerImageFromExtension($p_file)
  {
    $v_image = "file01-16.gif";
    PwsTraceFctStart(__FILE__, __LINE__, "PcsExplorerImageFromExtension", "file='$p_file'");

    // ----- Get extension
    $v_extension = substr(strrchr($p_file, '.'), 1);

    // ----- Look for image
    $v_extension_list = 'bmp gif gz ie php php3 piz tgz txt zip';
    $v_extension_array = explode(' ', $v_extension_list);
    for ($i=0; $i<sizeof($v_extension_array); $i++) {
      if ($v_extension_array[$i] == $v_extension) {
        $v_image = "file-".$v_extension."-16.gif";
      }
    }

    // ----- Return
    PwsTraceFctEnd(__FILE__, __LINE__, $v_image);
    return $v_image;
  }
  // --------------------------------------------------------------------------------

?>
